_positive = set(
    [
        "abba",
        "aptitude",
        "NO TRANSLATION",
        "absolu",
        "absolution",
        "absorbé",
        "abondant",
        "académique",
        "académie",
        "acceptable",
        "acceptation",
        "accessible",
        "accolade",
        "hébergement",
        "accompagnement",
        "accomplir",
        "accompli",
        "accomplissement",
        "accord",
        "responsabilité",
        "responsable",
        "accrédité",
        "NO TRANSLATION",
        "précis",
        "as",
        "atteindre",
        "réussite",
        "reconnaissance",
        "acquérir",
        "acquérir",
        "acrobate",
        "action",
        "réel",
        "acuité",
        "perspicacité",
        "adapter",
        "adaptable",
        "adresses",
        "expert",
        "NO TRANSLATION",
        "auxiliaire",
        "admirable",
        "amiral",
        "admiration",
        "admirer",
        "admirateur",
        "admissible",
        "adorable",
        "adoration",
        "adorer",
        "avance",
        "Avancée",
        "avancement",
        "avantage",
        "avantageux",
        "avènement",
        "aventure",
        "aventureux",
        "conseillé",
        "conseiller",
        "conseiller",
        "plaidoyer",
        "esthétique",
        "esthétique",
        "affable",
        "affection",
        "affilié",
        "affirmer",
        "affirmation",
        "affirmative",
        "affirmativement",
        "richesse",
        "affluent",
        "offrir",
        "NO TRANSLATION",
        "agile",
        "agilité",
        "se mettre d'accord",
        "agréable",
        "D'accord",
        "d'accord",
        "accord",
        "agriculture",
        "devant",
        "aide",
        "aider",
        "albâtre",
        "vigilance",
        "NO TRANSLATION",
        "vivant",
        "allay",
        "allégeance",
        "allegro",
        "soulager",
        "allégement",
        "allié",
        "admissible",
        "séduire",
        "séduisant",
        "allié",
        "tout-puissant",
        "aloha",
        "étonnamment",
        "ambassadeur",
        "ambition",
        "améliorer",
        "Amen",
        "accommodable",
        "modifier",
        "amende",
        "aménité",
        "aimable",
        "amical",
        "amnistie",
        "NO TRANSLATION",
        "amuser",
        "amusé",
        "amusement",
        "amusant",
        "analyste",
        "ancre",
        "ancrage",
        "ange",
        "angélique",
        "animer",
        "Animé",
        "antibiotiques",
        "antidote",
        "antifongique",
        "antique",
        "antiseptique",
        "aplomb",
        "apologétique",
        "s'excuser",
        "excuses",
        "apôtre",
        "applaudissements",
        "appréciation",
        "approbation",
        "approbation",
        "approuver",
        "approuvant",
        "apte",
        "aptitude",
        "archéologie",
        "ardent",
        "ardeur",
        "aristocratie",
        "aristocratique",
        "armure",
        "arôme",
        "susciter",
        "tableau",
        "art",
        "articuler",
        "articulation",
        "artisan",
        "NO TRANSLATION",
        "artistique",
        "ascendant",
        "ascension",
        "aspiration",
        "aspirer",
        "en herbe",
        "Assemblée",
        "assentiment",
        "affirmer",
        "les atouts",
        "aider",
        "assistance",
        "associer",
        "apaiser",
        "assurance",
        "assuré",
        "NO TRANSLATION",
        "étonnement",
        "astrologue",
        "astronaute",
        "astronome",
        "astucieux",
        "athlète",
        "athlétique",
        "atome",
        "expier",
        "expiation",
        "attachement",
        "réalisable",
        "réalisation",
        "préposé",
        "attention",
        "attentif",
        "attester",
        "avocat",
        "attraction",
        "attraction",
        "augmenter",
        "août",
        "tante",
        "aura",
        "de bon augure",
        "authentique",
        "authenticité",
        "auteur",
        "faisant autorité",
        "autorité",
        "autorisation",
        "autorisé",
        "avatar",
        "prix",
        "ay",
        "toujours",
        "bébé",
        "baccalauréat",
        "colonne vertébrale",
        "équilibre",
        "équilibré",
        "ballade",
        "ballet",
        "bulletin de vote",
        "baume",
        "banquet",
        "Baptême",
        "de baptême",
        "barde",
        "bonne affaire",
        "basketball",
        "bastion",
        "une baignoire",
        "faisceau",
        "radieux",
        "embellissement",
        "beau",
        "embellir",
        "beauté",
        "substrat rocheux",
        "Bière",
        "convenable",
        "se faire des amis",
        "croire",
        "bienfaiteur",
        "bénéfique",
        "avantage",
        "bienveillance",
        "bénin",
        "couchette",
        "fiancé",
        "amélioration",
        "boisson",
        "biblique",
        "bilingue",
        "naissance",
        "anniversaire",
        "irréprochable",
        "bénir",
        "béni",
        "bénédiction",
        "bénédictions",
        "félicité",
        "bienheureux",
        "exsangue",
        "Floraison",
        "fleur",
        "garde du corps",
        "audacieux",
        "audace",
        "traversin",
        "aubaine",
        "NO TRANSLATION",
        "prime",
        "livresque",
        "librairie",
        "aubaine",
        "généreux",
        "prime",
        "bouquet",
        "cerveaux",
        "bravoure",
        "déjeuner",
        "de mariée",
        "la mariée",
        "jeune marié",
        "demoiselle d'honneur",
        "éclairer",
        "luminosité",
        "brillant",
        "brocart",
        "frère",
        "fraternité",
        "fraternel",
        "copain",
        "construire",
        "bâtiment",
        "bouledogue",
        "blindé",
        "bouée",
        "buss",
        "majordome",
        "de beurre",
        "bien en chair",
        "bourdonner",
        "taxi",
        "cabinet",
        "café",
        "calculatrice",
        "veau",
        "calme",
        "canari",
        "Candide",
        "candidat",
        "confit",
        "capitaliste",
        "capitaine",
        "captiver",
        "captivant",
        "carrière",
        "prudent",
        "soigneusement",
        "caresse",
        "le concierge",
        "Carol",
        "Cascade",
        "en espèces",
        "catégorique",
        "répondre",
        "cathartique",
        "cathédrale",
        "prudent",
        "avec prudence",
        "célèbre",
        "célébrer",
        "fête",
        "céleste",
        "centre",
        "centurion",
        "cérébral",
        "la cérémonie",
        "certitude",
        "président",
        "présidente",
        "champion",
        "chant",
        "chargeur",
        "charitable",
        "charité",
        "charme",
        "charmant",
        "chasteté",
        "bavarder",
        "liste de contrôle",
        "acclamation",
        "de bonne humeur",
        "gaieté",
        "applaudissement",
        "NO TRANSLATION",
        "chimiste",
        "chérir",
        "Cerise",
        "chef de clan",
        "enfant",
        "enfance",
        "gazouiller",
        "ciseau",
        "chevalerie",
        "Chocolat",
        "choix",
        "chorale",
        "choral",
        "Refrain",
        "choisi",
        "chaudrée",
        "la chronique",
        "glousser",
        "église",
        "Cidre",
        "circoncision",
        "citoyen",
        "civil",
        "civilité",
        "civilisation",
        "civilisé",
        "voyant",
        "taper",
        "clarifier",
        "classique",
        "classique",
        "classiques",
        "classer",
        "nettoyer",
        "nettoyage",
        "propreté",
        "propre",
        "purifier",
        "nettoyage",
        "dégagement",
        "clarté",
        "clérical",
        "intelligent",
        "habileté",
        "Climax",
        "proximité",
        "fermeture",
        "NO TRANSLATION",
        "pitre",
        "coalition",
        "côte",
        "coexister",
        "convaincant",
        "cognitif",
        "la cohérence",
        "cohérent",
        "cohésif",
        "collectivement",
        "colonel",
        "colossal",
        "confort",
        "commandant",
        "commandant",
        "commémorer",
        "commémoration",
        "commémoratif",
        "saluer",
        "louable",
        "commentateur",
        "engagé",
        "commodore",
        "Commonwealth",
        "communiquer",
        "communicatif",
        "communion",
        "communauté",
        "commutation",
        "commuer",
        "un compagnon",
        "la compassion",
        "compatissant",
        "compatibilité",
        "compatible",
        "irrésistible",
        "compenser",
        "compensatoire",
        "compétence",
        "compétence",
        "compétent",
        "complaisance",
        "complément",
        "complémentaire",
        "complètement",
        "complétude",
        "compléter",
        "achèvement",
        "conformité",
        "conforme",
        "NO TRANSLATION",
        "composé",
        "compositeur",
        "calme",
        "comprendre",
        "complet",
        "camarade",
        "concentrique",
        "conciliation",
        "final",
        "concorde",
        "concordance",
        "condoléances",
        "fermer les yeux sur",
        "propice",
        "conductivité",
        "confédéré",
        "confiance",
        "sur de soi",
        "confirmé",
        "conformité",
        "agréable",
        "de félicitations",
        "congrégation",
        "congruence",
        "connaisseur",
        "conscience",
        "consciencieux",
        "conscience",
        "consécration",
        "préservation",
        "conserver",
        "considérable",
        "prévenant",
        "cohérence",
        "console",
        "consonne",
        "constance",
        "constant",
        "constitutionnel",
        "construction",
        "consommé",
        "contact",
        "contemplation",
        "contenu",
        "continuer",
        "contour",
        "contribuer",
        "donateur",
        "commodité",
        "pratique",
        "couvent",
        "convention",
        "au courant",
        "de la conversation",
        "convertir",
        "convaincre",
        "cool",
        "fraîcheur",
        "coopérer",
        "coopérant",
        "la coopération",
        "coopérative",
        "coeur",
        "couronnement",
        "société",
        "corporel",
        "correctif",
        "correspondance",
        "corroborer",
        "Cosmopolite",
        "confortable",
        "conseil",
        "Conseil",
        "conseiller",
        "compter",
        "comtesse",
        "courage",
        "courageux",
        "courtois",
        "courtoisie",
        "cour",
        "crique",
        "engagement",
        "berceau",
        "artisanat",
        "artisan",
        "crème",
        "créer",
        "Créatif",
        "foi",
        "credential",
        "crédibilité",
        "crédible",
        "crédit",
        "NO TRANSLATION",
        "crédité",
        "crescendo",
        "la critique",
        "couronnement",
        "crucial",
        "cristal",
        "caresse",
        "culinaire",
        "culmination",
        "cultiver",
        "cultivé",
        "cultivation",
        "Culture",
        "guérissable",
        "curiosité",
        "boucle",
        "coussin",
        "client",
        "mignonne",
        "coupeurs",
        "dame",
        "Danse",
        "audacieux",
        "chéri",
        "fringant",
        "fille",
        "Aube",
        "traiter",
        "cher",
        "débat",
        "décence",
        "décent",
        "déclaratoire",
        "dévouement",
        "défendre",
        "défendu",
        "défenseur",
        "défendre",
        "la défense",
        "respect",
        "définitive",
        "degré",
        "délectable",
        "déléguer",
        "délibérer",
        "délicieux",
        "délice",
        "Enchanté",
        "délicieux",
        "délivrance",
        "livraison",
        "la démocratie",
        "démontrable",
        "démonstratif",
        "profondeur",
        "descriptif",
        "mériter",
        "mérité",
        "designer",
        "souhaitable",
        "désirant",
        "désireux",
        "destination",
        "détecter",
        "détection",
        "détermination",
        "déterminé",
        "développer",
        "dévotionnel",
        "pieux",
        "dextérité",
        "diamant",
        "journal intime",
        "dictionnaire",
        "didactique",
        "diététique",
        "digne",
        "dignité",
        "diligence",
        "dîner",
        "diplomatie",
        "diplomatique",
        "réalisateur",
        "Découverte",
        "NO TRANSLATION",
        "discrétion",
        "discrétionnaire",
        "discussion",
        "désinfection",
        "disposé",
        "disséminer",
        "distillation",
        "distinction",
        "chansonnette",
        "diversifié",
        "dérivation",
        "divinité",
        "docteur",
        "auteur",
        "obstiné",
        "dauphin",
        "Don",
        "don",
        "sans aucun doute",
        "Colombe",
        "duveteux",
        "duo",
        "Duc",
        "durabilité",
        "durable",
        "respectueux",
        "désireux",
        "ardeur",
        "comte",
        "gagner",
        "sérieux",
        "sérieusement",
        "sérieux",
        "facilité",
        "servitude",
        "NO TRANSLATION",
        "manger",
        "extase",
        "en extase",
        "édification",
        "éduquer",
        "éduqué",
        "éducatif",
        "efficace",
        "efficacité",
        "Efficacité",
        "efficace",
        "effort",
        "éjaculation",
        "élaboration",
        "exalté",
        "aîné",
        "aînés",
        "élire",
        "électrique",
        "électricité",
        "élégance",
        "élégant",
        "élévation",
        "éligible",
        "élite",
        "éloquence",
        "éloquent",
        "élucider",
        "émancipation",
        "embrasse",
        "émérite",
        "éminence",
        "éminent",
        "éminemment",
        "NO TRANSLATION",
        "empathie",
        "habiliter",
        "imiter",
        "activer",
        "activation",
        "enchanter",
        "enchanté",
        "enchanteur",
        "NO TRANSLATION",
        "encourager",
        "encouragement",
        "encyclopédie",
        "effort",
        "doter",
        "doté",
        "dotation",
        "endurance",
        "supporter",
        "énergique",
        "engagé",
        "engageant",
        "améliorer",
        "prendre plaisir",
        "appréciant",
        "éclairer",
        "éclaircissement",
        "animer",
        "enrichir",
        "ensemble",
        "insigne",
        "entreprenant",
        "divertir",
        "amusé",
        "divertissant",
        "divertissement",
        "enthousiasme",
        "passionné",
        "NO TRANSLATION",
        "éphémérides",
        "épique",
        "exemple",
        "égalité",
        "également",
        "équilibre",
        "équité",
        "course",
        "érudit",
        "esprit",
        "essentiel",
        "établi",
        "estime",
        "esthétique",
        "éthique",
        "éthique",
        "à feuilles persistantes",
        "éternel",
        "évident",
        "évolution",
        "exalter",
        "exaltation",
        "exalté",
        "dépasser",
        "exceller",
        "excellence",
        "excellent",
        "échange",
        "excitable",
        "excitation",
        "exciter",
        "excité",
        "excitation",
        "passionnant",
        "exemplaire",
        "exemption",
        "euphorie",
        "exhorter",
        "exhortation",
        "existence",
        "exotique",
        "attendre",
        "attente",
        "opportun",
        "expédition",
        "expérimenté",
        "expert",
        "compétence",
        "Explique",
        "exquis",
        "exquisement",
        "étendre",
        "extensif",
        "supplémentaire",
        "extraordinaire",
        "dégager",
        "exubérance",
        "faciliter",
        "faits",
        "la faculté",
        "NO TRANSLATION",
        "juste",
        "équitablement",
        "Foi",
        "fidèle",
        "célébrité",
        "familier",
        "familiarité",
        "célèbre",
        "fameusement",
        "fantaisie",
        "fanfare",
        "fascinant",
        "fascination",
        "à la mode",
        "irréprochable",
        "favorable",
        "préféré",
        "favoritisme",
        "sans peur",
        "exploit",
        "fonctionnalité",
        "félicité",
        "compagnon",
        "camaraderie",
        "femelle",
        "fertile",
        "ferveur",
        "Festival",
        "de fête",
        "NO TRANSLATION",
        "fidélité",
        "fiesta",
        "enfin",
        "atours",
        "délicatesse",
        "boule de feu",
        "ignifuger",
        "fermeté",
        "NO TRANSLATION",
        "raccord",
        "fixation",
        "flatteur",
        "flotte",
        "la flexibilité",
        "floral",
        "couler",
        "fleuri",
        "affleurer",
        "en volant",
        "concentrer",
        "penchant",
        "aliments",
        "Football",
        "abstention",
        "avant",
        "aïeux",
        "précédent",
        "contremaître",
        "précurseur",
        "prévoir",
        "prévu",
        "prévoyance",
        "forger",
        "pardonner",
        "pardonné",
        "indulgent",
        "formatif",
        "formule",
        "NO TRANSLATION",
        "à venir",
        "fortifier",
        "courage",
        "forteresse",
        "chanceux",
        "fortune",
        "vers l'avant",
        "a trouvé",
        "fondation",
        "parfumé",
        "franc",
        "franchise",
        "fraternel",
        "liberté",
        "librement",
        "ami",
        "la convivialité",
        "amical",
        "relation amicale",
        "fringant",
        "gambader",
        "frugal",
        "fructueux",
        "remplir",
        "accomplissement",
        "plein",
        "pleinement",
        "amusement",
        "fondamental",
        "fusible",
        "la fusion",
        "Gain",
        "gagner",
        "galant",
        "galanterie",
        "en abondance",
        "jardin",
        "grenat",
        "garnison",
        "gazette",
        "équipement",
        "gemme",
        "général",
        "générosité",
        "généreuse",
        "génial",
        "génie",
        "distingué",
        "gentilhomme",
        "douceur",
        "noblesse",
        "authentique",
        "géranium",
        "cadeau",
        "doué",
        "gigantesque",
        "Pouffer de rire",
        "poutre",
        "donnant",
        "content de",
        "joie",
        "joie",
        "glisser",
        "lueur",
        "scintillant",
        "glorification",
        "glorifier",
        "gloire",
        "brillant",
        "lueur",
        "embrasé",
        "Dieu",
        "pieux",
        "don du ciel",
        "or",
        "bien",
        "beau",
        "la bonté",
        "des biens",
        "Bonne volonté",
        "magnifique",
        "gospel",
        "gouverne",
        "la grâce",
        "gracieux",
        "gracieux",
        "gracieusement",
        "l'obtention du diplôme",
        "petits enfants",
        "grandeur",
        "grand-mère",
        "subvention",
        "accordé",
        "reconnaissant",
        "satisfaire",
        "Reconnaissance",
        "plus grand",
        "grandeur",
        "vert",
        "salutation",
        "grégaire",
        "sourire",
        "blé à moudre",
        "grincer",
        "fond",
        "croître",
        "croissance",
        "garantie",
        "garde",
        "Gardien",
        "tutelle",
        "du gouverneur",
        "orientation",
        "guider",
        "guide",
        "gourou",
        "cran",
        "gymnaste",
        "habitat",
        "vigoureux",
        "pratique",
        "Heureusement",
        "bonheur",
        "content",
        "robuste",
        "harmonieusement",
        "harmonie",
        "récolte",
        "havre",
        "l'avance",
        "guérir",
        "guérison",
        "salubre",
        "en bonne santé",
        "sincère",
        "foyer",
        "chaleureusement",
        "céleste",
        "cieux",
        "soupeser",
        "casque",
        "assistant",
        "utile",
        "à base de plantes",
        "héros",
        "héroïque",
        "héroïque",
        "héroïne",
        "héroïsme",
        "l'apogée",
        "hilarant",
        "hilarité",
        "louer",
        "loisir",
        "vacances",
        "sainteté",
        "saint",
        "hommage",
        "homologie",
        "honnête",
        "honnêteté",
        "mon chéri",
        "voyage de noces",
        "honneur",
        "honorable",
        "espérer",
        "optimiste",
        "horizon",
        "hospitalité",
        "Ménage",
        "Ménagère",
        "étreinte",
        "humain",
        "humanitaire",
        "humanité",
        "humilié",
        "humblement",
        "humilité",
        "humoriste",
        "humoristique",
        "Hourra",
        "agriculture",
        "silence",
        "cabane",
        "hygiénique",
        "hymne",
        "idéalisme",
        "idole",
        "NO TRANSLATION",
        "éclairage",
        "illustrer",
        "illustre",
        "imaginatif",
        "immaculé",
        "immense",
        "immerger",
        "immortel",
        "donner",
        "impartial",
        "impartialité",
        "impeccable",
        "imperméable",
        "importance",
        "important",
        "impressionner",
        "impression",
        "améliorer",
        "amélioré",
        "amélioration",
        "améliorer",
        "improviser",
        "inaliénable",
        "inauguration",
        "incisif",
        "comprendre",
        "inclus",
        "comprenant",
        "compris",
        "augmenter",
        "indélébile",
        "indemnité",
        "indépendance",
        "indestructible",
        "individualité",
        "indomptable",
        "ineffable",
        "peu coûteux",
        "infaillible",
        "bébé",
        "infini",
        "infini",
        "influent",
        "information",
        "ingénieux",
        "héritage",
        "inimitable",
        "innocence",
        "innocent",
        "naïvement",
        "inoffensif",
        "innover",
        "innovation",
        "enquêteur",
        "enquête",
        "curieux",
        "inséparable",
        "insigne",
        "inspecteur",
        "inspiration",
        "inspirer",
        "inspiré",
        "instinctif",
        "instruire",
        "instruction",
        "instructeur",
        "instrumental",
        "assurer",
        "intact",
        "intégrité",
        "intellect",
        "intellectuel",
        "intelligence",
        "intelligent",
        "prévu",
        "rapports",
        "intérêt",
        "intéressé",
        "intéressant",
        "intérieur",
        "interlocutoire",
        "interlude",
        "intime",
        "intonation",
        "intrépide",
        "intuition",
        "intuitif",
        "invariablement",
        "inventif",
        "inventeur",
        "enquêter",
        "revigorer",
        "invitation",
        "inviter",
        "attrayant",
        "le fer",
        "irréductible",
        "irréfutable",
        "cagnotte",
        "confiture",
        "NO TRANSLATION",
        "emploi",
        "joindre",
        "rejoint",
        "joker",
        "plaisanterie",
        "journaliste",
        "périple",
        "jovial",
        "joie",
        "joyeux",
        "joyeux",
        "radieux",
        "jubilé",
        "judiciaire",
        "judicieux",
        "saut",
        "Justice",
        "justifiable",
        "justification",
        "souvenir",
        "Ken",
        "keynote",
        "clé de voûte",
        "gentil",
        "la gentillesse",
        "parenté",
        "Roi",
        "baiser",
        "chaton",
        "truc",
        "Chevalier",
        "connaissance",
        "connaissance",
        "gloire",
        "la main d'oeuvre",
        "agneau",
        "terre",
        "a atterri",
        "laser",
        "louable",
        "rire",
        "en riant",
        "rire",
        "lancement",
        "lauréat",
        "laurier",
        "lauriers",
        "prodiguer",
        "légitime",
        "conduire",
        "chef",
        "ligue",
        "apprendre",
        "apprentissage",
        "Maître de conférences",
        "marge de manœuvre",
        "légal",
        "légalisé",
        "légendaire",
        "lisibilité",
        "lisible",
        "loisir",
        "tranquille",
        "lemme",
        "indulgent",
        "leçon",
        "lettré",
        "niveau",
        "influence",
        "libérer",
        "libération",
        "liberté",
        "bibliothèque",
        "élément vital",
        "phare",
        "aimer",
        "linguiste",
        "Lion",
        "souple",
        "logique",
        "longévité",
        "seigneurie",
        "aimable",
        "amour",
        "charmant",
        "NO TRANSLATION",
        "amoureux",
        "aimant",
        "fidèle",
        "fidélité",
        "la chance",
        "chanceux",
        "succulent",
        "lustre",
        "lustré",
        "luxuriant",
        "luxueux",
        "luxe",
        "lyre",
        "lyrique",
        "magique",
        "aimant",
        "magnétisme",
        "magnétite",
        "magnificence",
        "magnifique",
        "jeune fille",
        "principale",
        "pilier",
        "majestueux",
        "majesté",
        "Majeur",
        "majorité",
        "gérer",
        "la gestion",
        "mandarin",
        "virilité",
        "manifesté",
        "viril",
        "manne",
        "maniéré",
        "manières",
        "fabricant",
        "Mars",
        "marqué",
        "commercialisable",
        "marquis",
        "mariage",
        "moelle",
        "marier",
        "maréchal",
        "merveille",
        "merveilleux",
        "merveilleusement",
        "masculin",
        "massage",
        "maîtriser",
        "chef-d'oeuvre",
        "la maîtrise",
        "camarade",
        "mariage",
        "matrone",
        "maximum",
        "maire",
        "Prairie",
        "mesuré",
        "médaille",
        "médiat",
        "la médiation",
        "médiateur",
        "médical",
        "NO TRANSLATION",
        "méditerranéen",
        "mélange",
        "mémento",
        "mémorable",
        "raccommodage",
        "règles",
        "mentor",
        "miséricordieux",
        "pitié",
        "fusionner",
        "mérite",
        "méritoire",
        "gaieté",
        "joyeux",
        "métropolitain",
        "courage",
        "microscopie",
        "obstétrique",
        "puissant",
        "mime",
        "conscient",
        "pleine conscience",
        "ministère",
        "miracle",
        "miraculeux",
        "gaieté",
        "missionnaire",
        "modèle",
        "modérer",
        "modérateur",
        "modeste",
        "modestie",
        "élan",
        "monétaire",
        "argent",
        "moine",
        "monument",
        "moral",
        "moralité",
        "morale",
        "mortier",
        "maternité",
        "motif",
        "mobile",
        "déménageur",
        "musclé",
        "la musique",
        "musical",
        "mutable",
        "mutuel",
        "sieste",
        "naturaliste",
        "navigable",
        "soigneusement",
        "nectar",
        "aiguille",
        "négocier",
        "négociateur",
        "voisin",
        "nerf",
        "se nicher",
        "la noblesse",
        "noble",
        "noble",
        "nomination",
        "normalité",
        "notable",
        "notables",
        "NO TRANSLATION",
        "notion",
        "nourriture",
        "Nombres",
        "infirmière",
        "garderie",
        "nourrir",
        "nutritif",
        "chêne",
        "oasis",
        "serment",
        "obéissance",
        "objectif",
        "obligeant",
        "observateur",
        "disponible",
        "évident",
        "occupant",
        "Occupation",
        "occuper",
        "offre",
        "officier",
        "décalage",
        "ramification",
        "omniscient",
        "ouverture",
        "opéra",
        "opportun",
        "opportunité",
        "optimisme",
        "optimiste",
        "option",
        "optionnel",
        "oracle",
        "discours solennel",
        "orchestre",
        "ordonné",
        "ordonné",
        "ordination",
        "biologique",
        "organisation",
        "organiser",
        "organisé",
        "orgasme",
        "originalité",
        "orné",
        "fleuri",
        "résultat",
        "surpasser",
        "vers l'extérieur",
        "fou de joie",
        "accablant",
        "la possession",
        "pacifique",
        "tampon",
        "rembourrage",
        "pagayer",
        "acceptable",
        "palliatif",
        "panacée",
        "panache",
        "NO TRANSLATION",
        "paprika",
        "parangon",
        "primordial",
        "pardon",
        "origine",
        "pariétal",
        "prendre part",
        "participation",
        "partenaire",
        "Partenariat",
        "la passion",
        "passionné",
        "Passe-temps",
        "pasteur",
        "Pâtisserie",
        "pâturage",
        "brevet",
        "la patience",
        "patient",
        "patriarcal",
        "mécène",
        "patronage",
        "Payer",
        "paix",
        "paisible",
        "paisible",
        "paon",
        "picorer",
        "particularité",
        "pedigree",
        "hors pair",
        "penchant",
        "apercevoir",
        "perceptible",
        "vivace",
        "parfait",
        "la perfection",
        "interprète",
        "perk",
        "autorisation",
        "perpétuité",
        "persistance",
        "persistant",
        "charmant",
        "pertinent",
        "pharmaceutique",
        "philanthrope",
        "philanthropie",
        "philosophe",
        "phénix",
        "phonétique",
        "médecin",
        "la physique",
        "physiologie",
        "physique",
        "choisir",
        "pique-nique",
        "pittoresque",
        "piété",
        "pilule",
        "oreiller",
        "pilote",
        "sommet",
        "pionnier",
        "pieux",
        "moelle",
        "pivot",
        "placide",
        "Planification",
        "espiègle",
        "Cour de récréation",
        "théâtre",
        "agréable",
        "heureux",
        "agréable",
        "gage",
        "plénier",
        "copieux",
        "plexus",
        "prune",
        "sonder",
        "peluche",
        "pli",
        "pointu",
        "police",
        "policier",
        "polonais",
        "brillant",
        "poli",
        "politesse",
        "NO TRANSLATION",
        "bassin",
        "le pape",
        "popularité",
        "popularisé",
        "population",
        "portable",
        "posséder",
        "potable",
        "puissance",
        "puissant",
        "puissamment",
        "entraine toi",
        "exercé",
        "entraine toi",
        "louange",
        "loué",
        "louable",
        "prier",
        "précaution",
        "précéder",
        "priorité",
        "précieux",
        "précis",
        "précision",
        "prédilection",
        "prédominant",
        "prééminent",
        "préférer",
        "premier",
        "locaux",
        "préparer",
        "préparé",
        "prescient",
        "présence",
        "présent",
        "présentable",
        "conservateur",
        "préserver",
        "Président",
        "prestige",
        "presto",
        "joli",
        "prévaloir",
        "la prévention",
        "inestimable",
        "fierté",
        "prêtre",
        "prêtrise",
        "sacerdotal",
        "primauté",
        "primaire",
        "premier",
        "apprêt",
        "prince",
        "princier",
        "Princesse",
        "principal",
        "parfait",
        "privilégié",
        "probité",
        "procédure",
        "procession",
        "procureur",
        "procurer",
        "prodigieux",
        "prodige",
        "producteur",
        "produisant",
        "production",
        "productif",
        "productivité",
        "métier",
        "professionnel",
        "professeur",
        "compétence",
        "compétent",
        "abondant",
        "le progrès",
        "progression",
        "progressive",
        "prolifique",
        "importance",
        "en bonne place",
        "promettre",
        "prometteur",
        "promotion",
        "soutenir",
        "correct",
        "prophète",
        "prophylactique",
        "proposition",
        "perspective",
        "prospérer",
        "la prospérité",
        "prospère",
        "protéger",
        "protéger",
        "protecteur",
        "protecteur",
        "fier",
        "prouver",
        "proverbial",
        "fournir",
        "fournir",
        "prudence",
        "prudent",
        "psaume",
        "Publique",
        "tirer",
        "chaire",
        "ponctuel",
        "ponctualité",
        "chiot",
        "purement",
        "purification",
        "purifier",
        "puriste",
        "pureté",
        "ronronner",
        "pittoresque",
        "qualifié",
        "qualification",
        "quête",
        "question",
        "rapidité",
        "tranquille",
        "silencieux",
        "quinine",
        "éclat",
        "radiant",
        "rayonner",
        "radio",
        "ravi",
        "ravissement",
        "rationnel",
        "lecteur",
        "facilement",
        "état de préparation",
        "en train de lire",
        "réaffirmer",
        "réal",
        "raison",
        "réconfort",
        "rassurer",
        "rabais",
        "refonte",
        "reçu",
        "recevoir",
        "NO TRANSLATION",
        "rendre",
        "réclamation",
        "incliner",
        "reconnaissable",
        "recommander",
        "réconciliation",
        "réexamen",
        "reconstruire",
        "reconstruction",
        "enregistreur",
        "récupérer",
        "récupération",
        "des loisirs",
        "récréatif",
        "rectifier",
        "rachat",
        "redresser",
        "affiner",
        "raffinement",
        "réforme",
        "réformation",
        "réformateur",
        "rafraîchissant",
        "remettre à neuf",
        "royal",
        "régent",
        "régularité",
        "réglementer",
        "réhabiliter",
        "réhabilitation",
        "rembourser",
        "remboursement",
        "renforcement",
        "rétablir",
        "réjouir",
        "réjouissance",
        "rajeunir",
        "rajeuni",
        "relaxation",
        "pertinent",
        "fiabilité",
        "fiable",
        "dépendance",
        "le soulagement",
        "soulager",
        "refaire",
        "remarquable",
        "NO TRANSLATION",
        "remède",
        "remise",
        "remodeler",
        "Renaissance",
        "rendre",
        "renouvellement",
        "rénover",
        "rénovation",
        "renommée",
        "renommé",
        "réorganiser",
        "réparation",
        "rembourser",
        "se repentir",
        "remplir",
        "rempli",
        "journaliste",
        "repos",
        "représentée",
        "reproducteur",
        "honorable",
        "porter secours",
        "réserve",
        "résident",
        "résilient",
        "résistif",
        "résolument",
        "Ressources",
        "le respect",
        "respectabilité",
        "respectable",
        "respectueux",
        "respectant",
        "respects",
        "répit",
        "resplendissant",
        "responsable",
        "sensible",
        "du repos",
        "reposant",
        "restitution",
        "réparatrice",
        "restaurer",
        "retenue",
        "reprise",
        "rétention",
        "réunion",
        "se délecter",
        "se réjouit",
        "révérer",
        "révérence",
        "révérend",
        "rêverie",
        "réviser",
        "la relance",
        "révolutionnaire",
        "récompense",
        "rythme",
        "rythmé",
        "ruban",
        "richesse",
        "cavalier",
        "vertueux",
        "légitime",
        "justement",
        "mûr",
        "mûrir",
        "en hausse",
        "rivetage",
        "roadster",
        "robuste",
        "Roche",
        "barre",
        "joyeux",
        "romance",
        "romantique",
        "le romantisme",
        "rompre",
        "enraciné",
        "rosé",
        "rota",
        "routine",
        "royalties",
        "rubrique",
        "Ruth",
        "sûr",
        "sauvegarde",
        "sauge",
        "Saint",
        "saint",
        "un salaire",
        "saillant",
        "salutaire",
        "saluer",
        "salut",
        "baume",
        "samouraï",
        "sanctification",
        "sanctifier",
        "sanctuaire",
        "sanguine",
        "sanitaire",
        "satin",
        "de manière satisfaisante",
        "satisfait",
        "enregistrer",
        "des économies",
        "saveur",
        "sarriette",
        "savvy",
        "savant",
        "Bourse d'études",
        "scientifique",
        "scientifique",
        "NO TRANSLATION",
        "But",
        "scribe",
        "scénario",
        "délicieux",
        "sculpture",
        "mer",
        "joint",
        "chevronné",
        "secrétariat",
        "ancienneté",
        "sensationnel",
        "sens",
        "sensibilité",
        "sensiblement",
        "sensualité",
        "sensuel",
        "sentimental",
        "sentimentalité",
        "sentinelle",
        "sérénité",
        "sermon",
        "sérum",
        "settlor",
        "sexe",
        "forme",
        "galbé",
        "partager",
        "abri",
        "berger",
        "éclat",
        "brillant",
        "achats",
        "épaule",
        "astucieux",
        "soie",
        "simplifier",
        "sincère",
        "la sincérité",
        "chanter",
        "séparément",
        "Monsieur",
        "la sororité",
        "qualifié",
        "habile",
        "ciel",
        "ardoise",
        "lisse",
        "mince",
        "svelte",
        "sourire",
        "souriant",
        "frappé",
        "douceur",
        "snicker",
        "sobriété",
        "sociable",
        "réconfort",
        "soldat",
        "solide",
        "solidité",
        "Solution",
        "solvabilité",
        "sonar",
        "sonate",
        "sonnet",
        "sonore",
        "apaiser",
        "apaisant",
        "NO TRANSLATION",
        "solidité",
        "soupe",
        "spa",
        "spacieux",
        "épagneul",
        "scintillait",
        "spécial",
        "NO TRANSLATION",
        "discours",
        "rapide",
        "orthographe",
        "pimenter",
        "esprit",
        "esprits",
        "splendide",
        "splendeur",
        "parrainer",
        "impeccable",
        "époux",
        "épicéa",
        "stable",
        "staccato",
        "inoxydable",
        "étalon",
        "vigoureux",
        "endurance",
        "permanent",
        "étoile",
        "lumière des étoiles",
        "étoilé",
        "majestueux",
        "déclaration",
        "statue",
        "statut",
        "étancher",
        "ferme",
        "stellaire",
        "intendant",
        "immobilité",
        "le magasin",
        "simple",
        "stratégique",
        "stratège",
        "force",
        "renforcer",
        "renforcement",
        "frappant",
        "étonnamment",
        "fortement",
        "structure",
        "Goujon",
        "étude",
        "solide",
        "sublimation",
        "substance",
        "substantiel",
        "réussir",
        "réussir",
        "Succès",
        "réussi",
        "succinct",
        "suffisance",
        "sucre",
        "adapté",
        "étouffant",
        "Soleil",
        "ensoleillé",
        "le coucher du soleil",
        "ensoleillement",
        "superbe",
        "surhumain",
        "supérieur",
        "supériorité",
        "Superman",
        "superstar",
        "supplication",
        "Provisions",
        "la fourniture",
        "prise en charge",
        "Supporter",
        "justificatif",
        "suprême",
        "suprêmement",
        "caution",
        "conjecture",
        "surpassant",
        "surprise",
        "arpentage",
        "survivre",
        "jurer",
        "doux",
        "amoureux",
        "ma chérie",
        "douceur",
        "bonbons",
        "rapide",
        "nager",
        "symbolique",
        "symétrique",
        "symétrie",
        "sympathique",
        "la sympathie",
        "symphonie",
        "synchroniser",
        "synergique",
        "synode",
        "tact",
        "conte",
        "Talent",
        "talisman",
        "parler",
        "bronzé",
        "tâche",
        "de bon goût",
        "délicieux",
        "apprendre",
        "prof",
        "La technologie",
        "tempérance",
        "tempéré",
        "défendable",
        "tenace",
        "ténacité",
        "location",
        "locataire",
        "soumissionner",
        "tendresse",
        "reconnaissant",
        "action de grâces",
        "théorique",
        "thérapeutique",
        "thérapeutique",
        "NO TRANSLATION",
        "de race",
        "réfléchi",
        "prévenance",
        "épargne",
        "frisson",
        "palpitant",
        "prospère",
        "trône",
        "chatouiller",
        "carrelage",
        "opportun",
        "clinquant",
        "Titre",
        "pain grillé",
        "tolérant",
        "tolérance",
        "Haut",
        "dureté",
        "la tour",
        "imposant",
        "traditionnel",
        "tranquille",
        "tranquillité",
        "transcendance",
        "transcendantal",
        "en voyageant",
        "Trésor",
        "arbre",
        "énormément",
        "tendance",
        "branché",
        "affluent",
        "hommage",
        "trigonométrie",
        "triomphe",
        "triomphant",
        "trophée",
        "trêve",
        "VRAI",
        "sûr",
        "vérité",
        "véracité",
        "tutelle",
        "tuteur",
        "double",
        "scintillement",
        "en fin de compte",
        "arbitre",
        "unanimité",
        "unanime",
        "modeste",
        "impartial",
        "incassable",
        "ininterrompu",
        "non contraint",
        "souligner",
        "compréhension",
        "souscrire",
        "indivise",
        "éternel",
        "sans équivoque",
        "se dérouler",
        "unification",
        "uniformément",
        "non infecté",
        "unique",
        "unisson",
        "unitaire",
        "uni",
        "unité",
        "Université",
        "illimité",
        "sans prétention",
        "incontestable",
        "incontestablement",
        "incontesté",
        "indemne",
        "généreux",
        "inégalée",
        "inébranlable",
        "soulèvement",
        "droit",
        "utilité",
        "huissier",
        "habituel",
        "utilitaire",
        "utopique",
        "vacances",
        "vaccin",
        "vaillant",
        "NO TRANSLATION",
        "de valeur",
        "avant-garde",
        "vaincre",
        "velours",
        "velouté",
        "vénérable",
        "vénération",
        "véracité",
        "verdoyant",
        "vérification",
        "vérifié",
        "en vérité",
        "véritable",
        "vernal",
        "verve",
        "vétéran",
        "vicaire",
        "Victor",
        "victorieux",
        "la victoire",
        "vigilance",
        "vigilant",
        "vigueur",
        "vigoureux",
        "villageois",
        "confirmé",
        "justification",
        "vierge",
        "virginité",
        "vertu",
        "vertueux",
        "vision",
        "visionnaire",
        "visite",
        "visiteur",
        "vital",
        "vitalité",
        "vivace",
        "vif",
        "vocabulaire",
        "bénévole",
        "voluptueux",
        "garant",
        "vœu",
        "les salaires",
        "garantie",
        "guerrier",
        "chien de garde",
        "vigilant",
        "gardien",
        "imperméable",
        "richesse",
        "imperméabiliser",
        "accueilli",
        "blanc",
        "blancheur",
        "sain",
        "guichet",
        "répandu",
        "volontiers",
        "volonté",
        "aubaine",
        "gagnant",
        "gagnant",
        "gains",
        "sans fil",
        "wis",
        "sagesse",
        "sage",
        "esprit",
        "résister",
        "wits",
        "spirituel",
        "sorcier",
        "utérus",
        "formidable",
        "merveilleusement",
        "merveilleux",
        "mot",
        "travail",
        "culte",
        "vaut",
        "digne",
        "wot",
        "écrivain",
        "Jeune",
        "plus jeune",
        "jeunesse",
        "zèle",
        "zélé",
        "zeste",
    ]
)

_negative = set(
    [
        "abandonner",
        "abandonné",
        "abandon",
        "enlèvement",
        "aberrant",
        "aberration",
        "abhorrer",
        "odieux",
        "abject",
        "anormal",
        "abolir",
        "abolition",
        "abominable",
        "abomination",
        "avorter",
        "Avortement",
        "abortif",
        "abrasion",
        "abroger",
        "abcès",
        "absence",
        "absent",
        "absent",
        "absentéisme",
        "absurde",
        "absurdité",
        "abuser de",
        "épouvantable",
        "abîme",
        "accident",
        "accidentel",
        "maudit",
        "accusation",
        "accusatif",
        "accusé",
        "accusateur",
        "accuser",
        "mal",
        "douloureux",
        "acide",
        "actionable",
        "additionneur",
        "dépendance",
        "adipeux",
        "juger",
        "admonition",
        "à la dérive",
        "frelaté",
        "adultère",
        "adversaire",
        "négatif",
        "adversité",
        "affliger",
        "affligé",
        "affliction",
        "affront",
        "peur",
        "conséquences",
        "arrière-goût",
        "aggravé",
        "aggravant",
        "aggravation",
        "agression",
        "agressif",
        "agresseur",
        "atterré",
        "agité",
        "agitation",
        "angoissant",
        "agonie",
        "échoué",
        "tous",
        "malade",
        "sans but",
        "airs",
        "alarme",
        "alarmant",
        "alcoolisme",
        "extraterrestre",
        "aliéner",
        "aliéné",
        "aliénation",
        "pension",
        "allégation",
        "alléguer",
        "distant",
        "altercation",
        "ambigu",
        "embuscade",
        "amnésie",
        "amphétamines",
        "anaconda",
        "anal",
        "anarchisme",
        "anarchiste",
        "anarchie",
        "anathème",
        "ancien",
        "colère",
        "angine",
        "pêche à la ligne",
        "en colère",
        "angoisse",
        "animosité",
        "animus",
        "annihiler",
        "annihilé",
        "annihilation",
        "ennuyer",
        "contrariété",
        "ennuyeux",
        "annuler",
        "annulation",
        "anomalie",
        "anonyme",
        "antagonisme",
        "antagoniste",
        "antagoniste",
        "anthrax",
        "Antéchrist",
        "antipathie",
        "vieilli",
        "antisocial",
        "antithèse",
        "anxiété",
        "anxieux",
        "apache",
        "apathique",
        "apathie",
        "puceron",
        "épouvantable",
        "appendicite",
        "appréhension",
        "inquiet",
        "appropriation",
        "archaïque",
        "difficile",
        "se disputer",
        "argument",
        "argumentatif",
        "aride",
        "armements",
        "accusation",
        "arrérages",
        "arrêter",
        "arrogance",
        "arrogant",
        "arsenic",
        "incendie volontaire",
        "artillerie",
        "cendre",
        "honteux",
        "cendres",
        "cul",
        "assaillir",
        "agresseur",
        "assassin",
        "assassiner",
        "assassinat",
        "agression",
        "Connard",
        "égaré",
        "astringent",
        "asile",
        "athéisme",
        "athérosclérose",
        "atroce",
        "atrocité",
        "atrophie",
        "attaque",
        "attaquer",
        "atténué",
        "atténuation",
        "audace",
        "austère",
        "austérité",
        "autocratique",
        "autopsie",
        "avalanche",
        "avarice",
        "vengeur",
        "averse",
        "aversion",
        "éviter",
        "évitement",
        "terrible",
        "maladresse",
        "de travers",
        "babiller",
        "babillage",
        "babouin",
        "vers l'arrière",
        "en arrière",
        "backwater",
        "des bactéries",
        "NO TRANSLATION",
        "mal",
        "blaireau",
        "mal",
        "méchanceté",
        "huissier",
        "appât",
        "balle",
        "rechigner",
        "NO TRANSLATION",
        "bandit",
        "fléau",
        "coup",
        "pétard",
        "bannir",
        "banni",
        "bannissement",
        "faillite",
        "la faillite",
        "banshee",
        "barbillon",
        "barbare",
        "barbare",
        "barbarisme",
        "écorce",
        "barré",
        "stérile",
        "barricade",
        "barrière",
        "sans fondement",
        "Connard",
        "Battre",
        "battu",
        "batterie",
        "bataille",
        "lutté",
        "champ de bataille",
        "paillard",
        "baïonnette",
        "porteur",
        "bête",
        "bestial",
        "battement",
        "arriver à",
        "mendier",
        "mendiant",
        "mendicité",
        "monstre",
        "redevable",
        "tardif",
        "rabaisser",
        "belligérant",
        "ceinture",
        "cintreuse",
        "privé",
        "deuil",
        "privé",
        "fou furieux",
        "bestial",
        "trahir",
        "trahison",
        "il faut se méfier",
        "égaré",
        "biais",
        "biaisé",
        "chamaillerie",
        "NO TRANSLATION",
        "bigot",
        "fanatique",
        "bile",
        "biopsie",
        "bouleau",
        "Lieu de naissance",
        "chienne",
        "mordre",
        "amèrement",
        "amertume",
        "bizarre",
        "noir",
        "blackjack",
        "chantage",
        "noirceur",
        "faire des reproches",
        "fade",
        "blasphématoire",
        "blasphème",
        "explosion",
        "flagrant",
        "bêtises",
        "flamber",
        "morne",
        "saignement",
        "défaut",
        "brûlure",
        "brûlé",
        "aveugle",
        "aveugle",
        "aveuglément",
        "cécité",
        "cloque",
        "gonflé",
        "goutte",
        "blocus",
        "effusion de sang",
        "sanguinaire",
        "sanglant",
        "tache",
        "ventilateur",
        "éteindre",
        "blues",
        "bluffer",
        "gaffe",
        "brouiller",
        "flou",
        "rougir",
        "se vantant",
        "tourbière",
        "faux",
        "ébullition",
        "passe-partout",
        "bombe",
        "bombarder",
        "bombardement",
        "bombardé",
        "esclavage",
        "obligations",
        "huer",
        "nigaud",
        "biberonner",
        "NO TRANSLATION",
        "ennui",
        "ennuyeuse",
        "emprunteur",
        "déranger",
        "déranger",
        "bas",
        "lié",
        "combat",
        "bovine",
        "garçon",
        "boycotter",
        "se vanter",
        "Cognac",
        "bravade",
        "bagarre",
        "effronté",
        "violation",
        "panne",
        "vertigineux",
        "NO TRANSLATION",
        "pot-de-vin",
        "corruption",
        "Brigade",
        "soufre",
        "poil",
        "bordée",
        "griller",
        "cassé",
        "cassé",
        "maison de prostitution",
        "bleu",
        "brunt",
        "brutal",
        "brutalité",
        "brute",
        "buffet",
        "punaise",
        "NO TRANSLATION",
        "bulbeux",
        "brute",
        "clochard",
        "bummer",
        "pénible",
        "bureaucratie",
        "bureaucrate",
        "cambrioleur",
        "cambriolage",
        "enterrement",
        "enterré",
        "burke",
        "brûlé",
        "cassé",
        "Boucher",
        "bout",
        "bourdonné",
        "cabale",
        "cacophonie",
        "goujat",
        "cadavre",
        "cage",
        "calculateur",
        "NO TRANSLATION",
        "appels",
        "faire campagne",
        "Annuler",
        "cancer",
        "chancre",
        "cannibale",
        "cannibalisme",
        "NO TRANSLATION",
        "captif",
        "captivité",
        "ravisseur",
        "Capturer",
        "carcasse",
        "carcinome",
        "cardiomyopathie",
        "négligence",
        "caricature",
        "carie",
        "carnage",
        "charnel",
        "carnivore",
        "cartel",
        "Cas",
        "cercueil",
        "caste",
        "victime",
        "cataracte",
        "catastrophe",
        "cathéter",
        "mise en garde",
        "céder",
        "cimetière",
        "censurer",
        "censurer",
        "cess",
        "cessation",
        "balle",
        "friction",
        "dépit",
        "défi",
        "le chaos",
        "chaotique",
        "charade",
        "payant",
        "chasse",
        "châtiment",
        "bavard",
        "pas cher",
        "Tricher",
        "cheesecake",
        "chicane",
        "puéril",
        "froid",
        "chloroforme",
        "étranglement",
        "choléra",
        "hacher",
        "corvée",
        "chronique",
        "cigarette",
        "clameur",
        "choc",
        "affrontement",
        "griffe",
        "cloître",
        "assombri",
        "trouble",
        "touffe",
        "maladroit",
        "cocaïne",
        "contraindre",
        "coercition",
        "cercueil",
        "du froid",
        "froidement",
        "froideur",
        "coliques",
        "effondrer",
        "collision",
        "connivence",
        "coma",
        "comateux",
        "combat",
        "combattant",
        "combatif",
        "incarcération",
        "agitation",
        "communisme",
        "communiste",
        "compétition",
        "se plaindre",
        "plainte",
        "complexé",
        "complexité",
        "compliquer",
        "compliqué",
        "complication",
        "compost",
        "compulsion",
        "obligatoire",
        "cacher",
        "caché",
        "dissimulation",
        "vanité",
        "vaniteux",
        "commotion cérébrale",
        "condamner",
        "condamnation",
        "condescendant",
        "condescendance",
        "confession",
        "confiner",
        "confiné",
        "accouchement",
        "confisquer",
        "confiscation",
        "incendie",
        "conflit",
        "contradictoire",
        "confondre",
        "confondu",
        "embrouiller",
        "confusion",
        "congestion",
        "prestidigitation",
        "conquête",
        "conspirateur",
        "conspirer",
        "consternation",
        "constipation",
        "contraindre",
        "contraint",
        "contrainte",
        "contagion",
        "contagieux",
        "contaminer",
        "contaminés",
        "contamination",
        "mépris",
        "méprisable",
        "méprisant",
        "contentieux",
        "contrebande",
        "contracté",
        "contredire",
        "contradiction",
        "contradictoire",
        "contraire",
        "contrasté",
        "contrevenir",
        "violation",
        "controversé",
        "controverse",
        "condamné",
        "conviction",
        "coopérative",
        "copie",
        "imitateur",
        "coroner",
        "corporel",
        "corps",
        "correction",
        "corrosion",
        "corrosif",
        "corrompu",
        "corrompant",
        "la corruption",
        "la toux",
        "conseiller",
        "coursing",
        "convoiter",
        "lâche",
        "lâcheté",
        "lâche",
        "crabby",
        "fissure",
        "fissuré",
        "craquer",
        "crampe",
        "à l'étroit",
        "manivelle",
        "excentrique",
        "merde",
        "crash",
        "crawl",
        "fou",
        "fou",
        "grincement",
        "créature",
        "se glisser",
        "la criminalité",
        "criminel",
        "criminalité",
        "reculer",
        "paralyser",
        "estropié",
        "crise",
        "croustillant",
        "critique",
        "critique",
        "critiquer",
        "escroc",
        "traverser",
        "accroupi",
        "croisé",
        "crucifixion",
        "brut",
        "cruel",
        "cruellement",
        "cruauté",
        "effritement",
        "croquer",
        "croisade",
        "écrasé",
        "écrasement",
        "croustillant",
        "cri",
        "pleurs",
        "crypte",
        "cocu",
        "coucou",
        "cueillir",
        "culpabilité",
        "coupable",
        "coupable",
        "culte",
        "lourd",
        "ventouses",
        "cur",
        "malédiction",
        "maudit",
        "maudire",
        "superficiel",
        "coupeur",
        "gorge folle",
        "Coupe",
        "cyanure",
        "cyclone",
        "kyste",
        "cytomégalovirus",
        "barboter",
        "démon",
        "idiot",
        "poignard",
        "dommage",
        "dégâts",
        "Zut",
        "damnation",
        "damné",
        "amortisseur",
        "pellicules",
        "dandy",
        "danger",
        "dangereux",
        "assombrir",
        "sombre",
        "obscurité",
        "en pointillé",
        "lâche",
        "étourdi",
        "désactiver",
        "impasse",
        "mortel",
        "sourd",
        "décès",
        "débâcle",
        "débauche",
        "débris",
        "dette",
        "débiteur",
        "pourriture",
        "pourri",
        "décédé",
        "tromperie",
        "trompeur",
        "tromper",
        "trompé",
        "tromper",
        "tromperie",
        "trompeur",
        "déclinaison",
        "déclin",
        "déclinant",
        "décomposition",
        "diminution",
        "décrémenter",
        "délabré",
        "décrier",
        "déduire",
        "diffamation",
        "diffamatoire",
        "défaut",
        "défaite",
        "vaincu",
        "défaut",
        "NO TRANSLATION",
        "défectueux",
        "sans défense",
        "report",
        "défi",
        "de défi",
        "carence",
        "déficit",
        "dégonfler",
        "déflation",
        "déformer",
        "déformé",
        "déformation",
        "frauder",
        "défunt",
        "defier",
        "dégénérescence",
        "dégénérer",
        "dégradation",
        "dégrader",
        "dégradant",
        "retard",
        "différé",
        "délétère",
        "effacement",
        "délinquance",
        "délinquant",
        "délirant",
        "délire",
        "inonder",
        "illusion",
        "délirant",
        "demande",
        "exigeant",
        "dément",
        "démence",
        "disparition",
        "démolir",
        "démolition",
        "démon",
        "démoniaque",
        "démoralisé",
        "le déni",
        "refusé",
        "dénoncer",
        "dénonciation",
        "Nier",
        "nier",
        "défunt",
        "Départ",
        "dépendance",
        "dépendance",
        "déplorable",
        "déplorer",
        "expulser",
        "déportation",
        "dépravé",
        "dépravation",
        "déprécier",
        "déprécié",
        "dépréciation",
        "déprimer",
        "déprimé",
        "déprimant",
        "dépression",
        "dépressif",
        "privation",
        "dérangé",
        "abandonné",
        "dérision",
        "dérogation",
        "dérogatoire",
        "profanation",
        "désert",
        "déserté",
        "désertion",
        "cesser",
        "désolation",
        "désespoir",
        "désespéré",
        "désespéré",
        "méprisable",
        "NO TRANSLATION",
        "despotique",
        "despotisme",
        "dépourvu",
        "détruit",
        "destructeur",
        "détruire",
        "destruction",
        "destructeur",
        "détachement",
        "détenir",
        "détenu",
        "retenue",
        "détériorer",
        "détérioré",
        "détérioration",
        "détester",
        "exploser",
        "diminuer",
        "détriment",
        "préjudiciable",
        "détritus",
        "dévaster",
        "dévastateur",
        "dévastation",
        "diable",
        "diabolique",
        "sournois",
        "dévolution",
        "dévorer",
        "diabolique",
        "diagnostic",
        "diatribe",
        "dictateur",
        "dictatorial",
        "dictature",
        "NO TRANSLATION",
        "des difficultés",
        "difficulté",
        "digress",
        "délabré",
        "diluer",
        "diminuer",
        "diminué",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "saleté",
        "sale",
        "invalidité",
        "désactiver",
        "désactivée",
        "mécontent",
        "être en désaccord",
        "en désaccord",
        "désaccord",
        "refusé",
        "décevoir",
        "désappointé",
        "décevant",
        "déception",
        "désapprobation",
        "désapprouver",
        "refusé",
        "désapprobateur",
        "catastrophe",
        "catastrophique",
        "ne pas croire",
        "rejets",
        "décharge",
        "la discipline",
        "désavouer",
        "décoloration",
        "décoloré",
        "malaise",
        "se déconnecter",
        "débranché",
        "coupure",
        "mécontentement",
        "cesser",
        "discontinuité",
        "discorde",
        "décourager",
        "découragement",
        "discrédit",
        "discriminer",
        "discriminant",
        "discrimination",
        "mépris",
        "maladie",
        "malade",
        "désincarné",
        "désengagement",
        "défiguré",
        "disgrâce",
        "NO TRANSLATION",
        "honteux",
        "mécontent",
        "dégoûter",
        "répugnant",
        "découragé",
        "décourageant",
        "malhonnête",
        "malhonnêteté",
        "déshonorer",
        "désillusion",
        "désinformation",
        "fourbe",
        "désintégrer",
        "désintégration",
        "désintéressé",
        "Ne pas aimer",
        "n'aimait pas",
        "disloquée",
        "lugubre",
        "consternation",
        "démembrement",
        "congédiement",
        "désobéissance",
        "désobéissant",
        "désobéir",
        "désordre",
        "désordonné",
        "désorganisé",
        "dénigrer",
        "désobligeant",
        "disparité",
        "impartial",
        "dissiper",
        "dispersion",
        "déplacer",
        "mécontent",
        "mécontentement",
        "disposition",
        "dépossédé",
        "contestation",
        "disqualification",
        "disqualifié",
        "disqualifier",
        "mépris",
        "ignoré",
        "de mauvaise réputation",
        "manque de respect",
        "irrespectueux",
        "perturbation",
        "insatisfaction",
        "dissension",
        "dissident",
        "mauvais service",
        "dissident",
        "dissolution",
        "dissonance",
        "dégoût",
        "désagréable",
        "déformé",
        "Distorsion",
        "distraire",
        "distraits",
        "distraire",
        "distraction",
        "éperdu",
        "détresse",
        "affligé",
        "pénible",
        "méfiance",
        "perturbation",
        "perturbé",
        "désuétude",
        "abandonné",
        "divergent",
        "cédé",
        "désinvestissement",
        "divorce",
        "vertiges",
        "étourdi",
        "ancré",
        "NO TRANSLATION",
        "doldrums",
        "aumône",
        "NO TRANSLATION",
        "dominant",
        "domination",
        "âne",
        "griffonnage",
        "condamner",
        "condamné",
        "jour du Jugement dernier",
        "doute",
        "douteux",
        "douter",
        "douche",
        "austère",
        "chute",
        "terne",
        "drainage",
        "inconvénient",
        "crainte",
        "horrible",
        "terriblement",
        "morne",
        "en buvant",
        "radotage",
        "drone",
        "tombant",
        "sécheresse",
        "noyer",
        "somnolence",
        "corvée",
        "ivre",
        "ivresse",
        "douteux",
        "terne",
        "stupide",
        "mannequin",
        "décharges",
        "dun",
        "cachot",
        "dupe",
        "duplicité",
        "contrainte",
        "poussière",
        "nain",
        "en train de mourir",
        "dysenterie",
        "tremblement de terre",
        "écoute",
        "décret",
        "efféminé",
        "égoïste",
        "énorme",
        "éjecter",
        "éjection",
        "élimination",
        "insaisissable",
        "émacié",
        "NO TRANSLATION",
        "embarrasser",
        "gênant",
        "embarras",
        "détournement de fonds",
        "embolie",
        "impliqué",
        "urgence",
        "enclave",
        "empiètement",
        "encombrement",
        "mettre en danger",
        "en voie de disparition",
        "endémique",
        "ennemi",
        "mise en vigueur",
        "énigmatique",
        "hostilité",
        "asservir",
        "esclave",
        "asservissement",
        "enchevêtré",
        "enchevêtrement",
        "entrailles",
        "envieux",
        "épidémie",
        "épilepsie",
        "éradiquer",
        "éradication",
        "effacer",
        "érosion",
        "se tromper",
        "errant",
        "erratique",
        "erratum",
        "erroné",
        "Erreur",
        "éclater",
        "éruption",
        "intensifier",
        "éviter",
        "espionnage",
        "séparé",
        "euthanasie",
        "évacuer",
        "évacuation",
        "éluder",
        "évasion",
        "expulser",
        "expulsion",
        "mal",
        "exacerber",
        "exacerbation",
        "exigeant",
        "exagérer",
        "exagéré",
        "examen",
        "exaspération",
        "les fouilles",
        "excès",
        "exciser",
        "exclu",
        "à l'exclusion",
        "exclusion",
        "excrément",
        "atroce",
        "excuse",
        "exécution",
        "bourreau",
        "échappement",
        "épuisé",
        "épuisement",
        "NO TRANSLATION",
        "exilé",
        "exorcisme",
        "expatrié",
        "expulser",
        "dépense",
        "dépenses",
        "expirer",
        "expiré",
        "explétif",
        "exploser",
        "explosion",
        "explosif",
        "exposé",
        "expropriation",
        "expulsion",
        "exterminer",
        "extermination",
        "disparu",
        "éteindre",
        "extrajudiciaire",
        "extrémité",
        "fabriquer",
        "fabrication",
        "fondu",
        "fèces",
        "échouer",
        "échec",
        "évanouissement",
        "déloyal",
        "faux",
        "tomber",
        "fallacieux",
        "erreur",
        "faillible",
        "chute",
        "jachère",
        "mensonge",
        "faussement",
        "falsification",
        "falsifier",
        "fausseté",
        "vaciller",
        "famine",
        "fanatique",
        "farce",
        "grotesque",
        "jeûne",
        "graisse",
        "fatal",
        "Fatalité",
        "sort",
        "fatigue",
        "fatigué",
        "gras",
        "faute",
        "défectueux",
        "faon",
        "peur",
        "craintif",
        "craintivement",
        "craignant",
        "fébrile",
        "fécale",
        "excréments",
        "frais",
        "faible",
        "feint",
        "est tombée",
        "criminel",
        "crime",
        "fermenter",
        "féroce",
        "férocité",
        "querelle",
        "féodal",
        "féodalisme",
        "fébrile",
        "fiasco",
        "mensonge",
        "inconstant",
        "fictif",
        "démon",
        "féroce",
        "bats toi",
        "combat",
        "obstruction",
        "saleté",
        "crasseux",
        "armes à feu",
        "convient",
        "flasque",
        "mou",
        "signaler",
        "flagrant",
        "flocon",
        "rabat",
        "flatulence",
        "faire étalage",
        "défaut",
        "Puce",
        "NO TRANSLATION",
        "toison",
        "charnu",
        "reculer",
        "fouetter",
        "fiasco",
        "patauger",
        "grippe",
        "fluctuation",
        "ennemi",
        "déjoué",
        "folie",
        "imbécile",
        "insensé",
        "la bêtise",
        "fourrage",
        "incursion",
        "interdire",
        "interdiction",
        "Obliger",
        "forcé",
        "de force",
        "pressentiment",
        "saisir",
        "renoncer",
        "étranger",
        "étranger",
        "prévenu",
        "déclarer forfait",
        "confisqué",
        "confiscation",
        "falsification",
        "oublier",
        "oublié",
        "désespéré",
        "informe",
        "fornication",
        "abandonner",
        "abandonné",
        "faute",
        "fracture",
        "fragile",
        "fragilité",
        "frénétique",
        "fraude",
        "frauduleux",
        "chargé",
        "combat",
        "effiloché",
        "bizarre",
        "gel",
        "frénétique",
        "frénétique",
        "frénésie",
        "frette",
        "la frayeur",
        "effrayer",
        "effrayé",
        "affreux",
        "froid",
        "frivole",
        "gelure",
        "mousse",
        "froncer les sourcils",
        "renfrogné",
        "infructueux",
        "frustrer",
        "frustré",
        "frustration",
        "truquer",
        "fugitif",
        "tâtonner",
        "fumée",
        "fumant",
        "champignon",
        "trouille",
        "furieux",
        "scandale",
        "fureur",
        "agitation",
        "difficile",
        "futile",
        "futilité",
        "gaby",
        "gag",
        "fiel",
        "potence",
        "pari",
        "joueur",
        "jeux d'argent",
        "gang",
        "prison",
        "écart",
        "des ordures",
        "criard",
        "garnir",
        "entaille",
        "halètement",
        "NO TRANSLATION",
        "décharné",
        "gent",
        "gériatrique",
        "horrible",
        "ghetto",
        "fantomatique",
        "charabia",
        "glacial",
        "éblouissement",
        "flagrant",
        "désinvolte",
        "obscurité",
        "sombre",
        "maussade",
        "surabondance",
        "gourmandise",
        "gnome",
        "lutin",
        "impie",
        "blennorragie",
        "goo",
        "sang",
        "gorge",
        "gorille",
        "sanglant",
        "potins",
        "gouge",
        "goutte",
        "gouvernement",
        "saisir",
        "saisir",
        "grille",
        "râpé",
        "grille",
        "la tombe",
        "avidité",
        "glouton",
        "grenade",
        "douleur",
        "grief",
        "se plaindre",
        "grave",
        "sinistre",
        "crasse",
        "crasseux",
        "broyage",
        "macabre",
        "grizzly",
        "gémissement",
        "NO TRANSLATION",
        "brut",
        "grotesque",
        "à la terre",
        "sans fondement",
        "grognement",
        "grondement",
        "rancune",
        "à contrecœur",
        "horrible",
        "bourru",
        "plaindre",
        "grincheux",
        "guérilla",
        "ruse",
        "guillotine",
        "culpabilité",
        "coupable",
        "apparence",
        "mouette",
        "crédule",
        "pistolet",
        "jet",
        "guzzling",
        "gitan",
        "vieille sorcière",
        "hâve",
        "poilu",
        "à mi-chemin",
        "hallucination",
        "licou",
        "arrêter",
        "entraver",
        "tendon",
        "handicap",
        "pendaison",
        "bourreau",
        "harceler",
        "présage",
        "endurci",
        "dureté",
        "épreuves",
        "prostituée",
        "nuire",
        "nocif",
        "poignant",
        "harry",
        "dureté",
        "hacher",
        "haschisch",
        "précipité",
        "haine",
        "odieux",
        "haïr",
        "haine",
        "hautain",
        "hanter",
        "hanté",
        "ravage",
        "danger",
        "dangereux",
        "brume",
        "mal de tête",
        "capiteux",
        "audition",
        "ouï-dire",
        "corbillard",
        "chagrin",
        "brûlures d'estomac",
        "sans coeur",
        "païen",
        "fortement",
        "talon",
        "augmenter",
        "odieux",
        "enfer",
        "atroce",
        "sans espoir",
        "impuissance",
        "hémorragie",
        "les hémorroïdes",
        "hérésie",
        "hérétique",
        "hermaphrodite",
        "héroïne",
        "herpès",
        "herpèsvirus",
        "hésitation",
        "caché",
        "hideux",
        "entrave",
        "obstacle",
        "hippie",
        "sifflement",
        "sifflant",
        "frappé",
        "jusqu'ici",
        "ruche",
        "rauque",
        "chenu",
        "canular",
        "clochard",
        "porc",
        "creux",
        "holocauste",
        "sans abri",
        "le mal du pays",
        "homicide",
        "homicide",
        "homosexualité",
        "capuche",
        "accroché",
        "huée",
        "désespéré",
        "désespoir",
        "horde",
        "horrible",
        "horriblement",
        "affreux",
        "horrible",
        "horrifié",
        "effroyable",
        "horreur",
        "horreurs",
        "otage",
        "hostile",
        "hostilités",
        "hostilité",
        "hurler",
        "souffler",
        "fumisterie",
        "humilier",
        "humiliant",
        "humiliation",
        "pressentiment",
        "affamé",
        "chasseur",
        "chasse",
        "ouragan",
        "pressé",
        "blesser",
        "nuisible",
        "blesser",
        "Hustler",
        "hydre",
        "hydrocéphalie",
        "hype",
        "hyperbole",
        "hypocrisie",
        "hypocrite",
        "hypocrite",
        "hystérie",
        "hystérique",
        "idiotie",
        "idiot",
        "idiot",
        "oisif",
        "idolâtrie",
        "ignorance",
        "ignorant",
        "ignorer",
        "mauvais",
        "illégal",
        "illégalité",
        "illisible",
        "illégitime",
        "illicite",
        "analphabète",
        "maladie",
        "illogique",
        "illusion",
        "imité",
        "imitation",
        "immature",
        "immaturité",
        "immoral",
        "immoralité",
        "impair",
        "déficience",
        "infranchissable",
        "impatience",
        "impatient",
        "accuser",
        "mise en accusation",
        "entraver",
        "imperfection",
        "imparfaitement",
        "imiter",
        "imitation",
        "implacable",
        "impliquer",
        "impoli",
        "imposition",
        "impossible",
        "impuissance",
        "impuissant",
        "mettre en fourrière",
        "impraticable",
        "emprisonner",
        "détenu",
        "emprisonnement",
        "inconvenance",
        "imprudent",
        "impur",
        "impureté",
        "imputation",
        "incapacité",
        "inaccessible",
        "inexacte",
        "inaction",
        "inactivité",
        "insuffisance",
        "inadéquat",
        "inadmissible",
        "inepte",
        "inapplicable",
        "inapproprié",
        "inattention",
        "inaudible",
        "incalculable",
        "incapacité",
        "incarcération",
        "au cas où",
        "incendiaire",
        "encens",
        "incessant",
        "inceste",
        "incestueux",
        "incinération",
        "inciter",
        "inclément",
        "incohérent",
        "incompatible",
        "incompétence",
        "incompétent",
        "incomplétude",
        "incompréhensible",
        "incongru",
        "sans conséquence",
        "inconsidéré",
        "incohérence",
        "incommode",
        "Incorrect",
        "incrédule",
        "incrimination",
        "incube",
        "encourir",
        "incurable",
        "incursion",
        "indécent",
        "indécision",
        "indécis",
        "indéfendable",
        "indemniser",
        "indenture",
        "indéterminé",
        "accuser",
        "accusation",
        "indifférence",
        "indigent",
        "indigné",
        "indignation",
        "indistinct",
        "endoctrinement",
        "indolent",
        "inefficace",
        "inefficace",
        "inefficacité",
        "inefficace",
        "inepte",
        "ineptie",
        "inégalité",
        "inéquitable",
        "inerte",
        "inexcusable",
        "NO TRANSLATION",
        "inexpérimenté",
        "inexplicable",
        "infâme",
        "infamie",
        "infanticide",
        "infantile",
        "infarctus",
        "infecter",
        "infection",
        "infectieux",
        "inférieur",
        "infériorité",
        "enfer",
        "infertilité",
        "infestation",
        "infidèle",
        "infidélité",
        "infirme",
        "infirmité",
        "inflammation",
        "gonflé",
        "inflation",
        "infliger",
        "affliction",
        "grippe",
        "informateur",
        "infraction",
        "rarement",
        "infraction",
        "inhiber",
        "inhospitalier",
        "inhumain",
        "inhumanité",
        "hostile",
        "iniquité",
        "injonction",
        "blesser",
        "blessé",
        "préjudiciable",
        "blessure",
        "injustice",
        "détenu",
        "inopérant",
        "insensé",
        "folie",
        "peu sûr",
        "insécurité",
        "insidieux",
        "insignifiance",
        "insignifiant",
        "insipide",
        "insolent",
        "insolvabilité",
        "insolvable",
        "instabilité",
        "susciter",
        "instigation",
        "insuffisance",
        "insuffisant",
        "insuffisamment",
        "insulter",
        "insultant",
        "insurgé",
        "insurmontable",
        "insurrection",
        "entre",
        "interdiction",
        "ingérence",
        "inhumation",
        "interrompre",
        "interrompu",
        "intestat",
        "intimider",
        "intimidation",
        "intolérable",
        "intolérance",
        "intolérant",
        "ivre",
        "intraitable",
        "intrigue",
        "intrus",
        "intrusion",
        "intrusif",
        "envahir",
        "envahisseur",
        "invalider",
        "annulation",
        "invalidité",
        "invasion",
        "involontaire",
        "involution",
        "furieux",
        "NO TRANSLATION",
        "fers",
        "irrationnel",
        "irrationalité",
        "irréconciliable",
        "irrégulier",
        "irrégularité",
        "sans importance",
        "irréparable",
        "irresponsable",
        "irrévérencieux",
        "irrévocable",
        "irritabilité",
        "irritable",
        "irritant",
        "irritation",
        "isolé",
        "isolement",
        "jacasser",
        "prison",
        "jargon",
        "discordant",
        "jaunisse",
        "jaloux",
        "jalousie",
        "compromettre",
        "péril",
        "John",
        "blague",
        "NO TRANSLATION",
        "fouillis",
        "déchet",
        "junte",
        "juvénile",
        "kern",
        "donner un coup",
        "kidnapper",
        "tuer",
        "meurtre",
        "cerf-volant",
        "glas",
        "noué",
        "laborieux",
        "laborieux",
        "labyrinthe",
        "manquer de",
        "manquant",
        "terne",
        "chargé",
        "décalage",
        "en retard",
        "repaire",
        "complainte",
        "glissement de terrain",
        "languissant",
        "languir",
        "languissant",
        "laps",
        "vol",
        "fouetter",
        "en retard",
        "retard",
        "latent",
        "latrines",
        "ridicule",
        "lave",
        "anarchie",
        "procès",
        "avocat",
        "relâché",
        "laxatif",
        "paresseux",
        "fuite",
        "fuite",
        "qui fuit",
        "laisser",
        "sangsue",
        "sangsues",
        "NO TRANSLATION",
        "citron",
        "lèpre",
        "lesbienne",
        "réduire",
        "moindre",
        "mortel",
        "léthargie",
        "leucémie",
        "prélèvement",
        "obscène",
        "liaison",
        "menteur",
        "calomnie",
        "lécher",
        "mensonge",
        "sans vie",
        "limité",
        "boiter",
        "peluche",
        "alcool",
        "indifférent",
        "plaideur",
        "plaider",
        "litige",
        "litigieux",
        "litière",
        "livide",
        "pain",
        "flâneur",
        "NO TRANSLATION",
        "détester",
        "répugnance",
        "détestable",
        "lobbyiste",
        "NO TRANSLATION",
        "criquet",
        "élevé",
        "solitude",
        "solitaire",
        "solitaire",
        "loo",
        "métier à tisser",
        "plongeon",
        "cinglé",
        "butin",
        "perdre",
        "perdant",
        "perte",
        "perdu",
        "intensité",
        "salon",
        "pou",
        "inférieur",
        "abaissement",
        "le plus bas",
        "basses terres",
        "humble",
        "ridicule",
        "exploitation forestière",
        "bosse",
        "grumeleux",
        "folie",
        "fou",
        "embardée",
        "leurre",
        "sinistre",
        "se cacher",
        "cachette",
        "luxuriant",
        "luxure",
        "lubrique",
        "mensonge",
        "lyncher",
        "masse",
        "furieux",
        "madden",
        "fou",
        "la démence",
        "mafia",
        "asticot",
        "de fortune",
        "maladie",
        "malaise",
        "paludisme",
        "malveillant",
        "malversation",
        "malformation",
        "malice",
        "mal intentionné",
        "calomnier",
        "malignité",
        "malin",
        "faute professionnelle",
        "mandamus",
        "NO TRANSLATION",
        "mutiler",
        "la manie",
        "maniaque",
        "maniaque",
        "manipuler",
        "manipulation",
        "homicide involontaire",
        "fumier",
        "mar",
        "marge",
        "bordeaux",
        "martingale",
        "martyr",
        "martyre",
        "masochisme",
        "massacre",
        "matérialisme",
        "matérialiste",
        "sinueux",
        "sans signification",
        "rougeole",
        "se mêler",
        "médiocre",
        "médiocrité",
        "mélancolique",
        "mélancolie",
        "mêlée",
        "mélodrame",
        "effondrement",
        "menace",
        "menaçant",
        "servile",
        "mercenaire",
        "sans merci",
        "désordre",
        "désordonné",
        "métastase",
        "méthanol",
        "moisissure",
        "milice",
        "mimétisme",
        "minimiser",
        "le minimum",
        "minorité",
        "NO TRANSLATION",
        "mauvaise conduite",
        "fausse couche",
        "sottises",
        "malicieux",
        "idée fausse",
        "inconduite",
        "misérable",
        "misérablement",
        "misère",
        "malheur",
        "égaré",
        "mésaventure",
        "interprétation erronée",
        "tromper",
        "trompeur",
        "mauvaise gestion",
        "décalage",
        "abus de langage",
        "égarer",
        "mal placé",
        "dénaturer",
        "fausse déclaration",
        "déformé",
        "disparu",
        "déclaration inexacte",
        "erreur",
        "trompé",
        "maîtresse",
        "NO TRANSLATION",
        "mal comprendre",
        "malentendu",
        "abuser",
        "mite",
        "foule",
        "moquerie",
        "railleur",
        "attentat à la pudeur",
        "monochrome",
        "monopoliste",
        "mousson",
        "monstre",
        "monstruosité",
        "de mauvaise humeur",
        "discutable",
        "morbide",
        "morbidité",
        "morgue",
        "moribond",
        "idiot",
        "débile",
        "morceau",
        "mortel",
        "mortalité",
        "mortification",
        "mortuaire",
        "moustique",
        "faire le deuil",
        "triste",
        "deuil",
        "boue",
        "boue",
        "confusion",
        "embrouillé",
        "boueux",
        "manchon",
        "mule",
        "maman",
        "marmonner",
        "oreillons",
        "meurtre",
        "meurtrier",
        "meurtrier",
        "sombre",
        "NO TRANSLATION",
        "de moisi",
        "mutant",
        "mutilé",
        "mutilation",
        "mutinerie",
        "NO TRANSLATION",
        "museau",
        "myopie",
        "nab",
        "nadir",
        "NO TRANSLATION",
        "naïve",
        "sans nom",
        "couche",
        "narcotique",
        "méchant",
        "vilain",
        "la nausée",
        "nauséeux",
        "NO TRANSLATION",
        "nécessaire",
        "nécessiteux",
        "infâme",
        "négation",
        "négatif",
        "négligence",
        "négligé",
        "négliger",
        "négligence",
        "négligent",
        "NO TRANSLATION",
        "nègre",
        "népotisme",
        "nerveux",
        "bas",
        "ortie",
        "névralgie",
        "névrose",
        "névrosé",
        "nicotine",
        "nègre",
        "cauchemar",
        "nihilisme",
        "bruit",
        "bruyant",
        "NO TRANSLATION",
        "absurdité",
        "absurde",
        "nœud coulant",
        "le néant",
        "nuisible",
        "nuisance",
        "NO TRANSLATION",
        "annuler",
        "engourdi",
        "engourdissement",
        "NO TRANSLATION",
        "lourdaud",
        "obèse",
        "obésité",
        "obi",
        "obit",
        "nécrologie",
        "objection",
        "répréhensible",
        "obliger",
        "débiteur",
        "effacer",
        "oblitéré",
        "oblitération",
        "oubli",
        "odieux",
        "obscène",
        "obscénité",
        "obscurité",
        "obstacle",
        "obstiné",
        "obstruer",
        "obstruction",
        "obstructif",
        "obtus",
        "occulte",
        "singularité",
        "odieux",
        "odeur",
        "offenser",
        "offensé",
        "délinquant",
        "infraction",
        "offensive",
        "désinvolte",
        "offing",
        "ogre",
        "olfactif",
        "oligarchie",
        "présage",
        "de mauvais augure",
        "omettre",
        "lourd",
        "fardeau",
        "suinter",
        "opaque",
        "opératique",
        "opiacé",
        "dogmatique",
        "opium",
        "adversaire",
        "s'opposer",
        "opposé",
        "opposition",
        "opprimer",
        "oppression",
        "oppressif",
        "oppresseur",
        "orc",
        "supplice",
        "l'artillerie",
        "orphelin",
        "en apparence",
        "évincer",
        "banni",
        "tollé",
        "appentis",
        "bizarre",
        "hors la loi",
        "outrage",
        "ovation",
        "autoritaire",
        "surcharger",
        "couvert",
        "exagérer",
        "surdosage",
        "en retard",
        "surestimé",
        "débordement",
        "envahi",
        "surcharge",
        "trop payé",
        "maîtriser",
        "irrésistible",
        "trop cher",
        "surveillance",
        "renverser",
        "renverser",
        "submerger",
        "submergé",
        "dû",
        "oxydation",
        "douleur",
        "peiné",
        "douloureux",
        "douloureusement",
        "des douleurs",
        "paralysie",
        "pandémie",
        "NO TRANSLATION",
        "panique",
        "paralysie",
        "paralysé",
        "paranoïa",
        "parasite",
        "NO TRANSLATION",
        "perroquet",
        "parcimonieux",
        "partisan",
        "NO TRANSLATION",
        "passif",
        "passivité",
        "pièce",
        "pathétique",
        "condescendant",
        "NO TRANSLATION",
        "manque",
        "pauvre",
        "pion",
        "remboursement",
        "Paiement",
        "particularités",
        "piéton",
        "pénal",
        "peine",
        "pénétration",
        "pénitencier",
        "perdition",
        "péril",
        "périlleux",
        "périr",
        "périssable",
        "périt",
        "périr",
        "parjure",
        "pernicieux",
        "auteur",
        "perpétuation",
        "perplexe",
        "perplexité",
        "persécuter",
        "persécution",
        "perturbation",
        "coqueluche",
        "pervers",
        "perversion",
        "pervertir",
        "pervers",
        "pessimisme",
        "pessimiste",
        "ravageur",
        "peste",
        "animal de compagnie",
        "petit",
        "fantôme",
        "flegme",
        "faux",
        "piquet",
        "piquets de grève",
        "cornichon",
        "porc",
        "Pigeon",
        "pieux",
        "pillage",
        "souteneur",
        "bouton",
        "pin",
        "pignon",
        "piquer",
        "le piratage",
        "pirate",
        "pistolet",
        "piège",
        "plagiat",
        "peste",
        "demandeur",
        "plaqué",
        "joueur",
        "plaidoyer",
        "situation critique",
        "laborieux",
        "plomb",
        "pillage",
        "plonger",
        "pneumonie",
        "braconnage",
        "inutile",
        "poison",
        "empoisonné",
        "empoisonnement",
        "toxique",
        "poussée",
        "polémique",
        "polio",
        "polluer",
        "la pollution",
        "la polygamie",
        "pompe",
        "pompeux",
        "lourd",
        "pauvrement",
        "pop",
        "porc-épic",
        "porno",
        "porno",
        "pornographique",
        "pornographie",
        "pose",
        "possédé",
        "possession",
        "posthume",
        "report",
        "livre",
        "la pauvreté",
        "impuissant",
        "farce",
        "précaire",
        "enceinte",
        "prédateur",
        "situation difficile",
        "grossesse",
        "préjudice",
        "partial",
        "préjudiciable",
        "prémédité",
        "pression",
        "présomptueux",
        "faire semblant",
        "prétendu",
        "prétendre",
        "prétexte",
        "prétentions",
        "préventif",
        "proie",
        "piquer",
        "épineux",
        "prison",
        "prisonnier",
        "privé",
        "problème",
        "tergiverser",
        "procrastination",
        "profane",
        "impiété",
        "profusion",
        "interdit",
        "interdiction",
        "prolonger",
        "promiscuité",
        "la propagande",
        "poursuivre",
        "poursuite",
        "prostituée",
        "la prostitution",
        "provocation",
        "provoquant",
        "prier",
        "indiscret",
        "psychose",
        "journaliste",
        "bouffi",
        "coup de poing",
        "âcre",
        "punir",
        "puni",
        "punir",
        "Châtiment",
        "punitif",
        "purgatoire",
        "purge",
        "pus",
        "charlatan",
        "bourbier",
        "Caille",
        "dilemme",
        "querelle",
        "annuler",
        "réprimer",
        "discutable",
        "mercure",
        "quitter",
        "trembler",
        "frémissant",
        "quiz",
        "populace",
        "enragé",
        "rage",
        "grille",
        "raquette",
        "radiation",
        "radioactif",
        "radon",
        "rage",
        "rage",
        "chiffons",
        "raid",
        "rail",
        "RAM",
        "randonnée",
        "déchaînement",
        "rance",
        "une rançon",
        "râpé",
        "rapaces",
        "coquin",
        "téméraire",
        "rat",
        "évaluation",
        "rauque",
        "vorace",
        "délirant",
        "réactionnaire",
        "arrière",
        "rebelle",
        "réprimander",
        "réfuter",
        "récalcitrant",
        "récession",
        "récidive",
        "téméraire",
        "insouciance",
        "redondant",
        "reflux",
        "réfractaire",
        "refus",
        "refuser",
        "refusé",
        "régresser",
        "régression",
        "le regret",
        "regrettable",
        "regretté",
        "regrettant",
        "réglementaire",
        "rêne",
        "rejeter",
        "rejeté",
        "rejet",
        "rejette",
        "rechute",
        "relégation",
        "renoncer",
        "réticent",
        "renvoi",
        "correctif",
        "négligent",
        "remords",
        "suppression",
        "retirer",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "renégat",
        "renoncer",
        "renonciation",
        "NO TRANSLATION",
        "repoussant",
        "repousser",
        "réprimer",
        "répression",
        "réprimande",
        "réimpression",
        "représailles",
        "reproche",
        "république",
        "répudiation",
        "répulsion",
        "annuler",
        "annulation",
        "renvoyé",
        "irrité",
        "rancœur",
        "démissionner",
        "démission",
        "résigné",
        "résister",
        "la résistance",
        "résistant",
        "résister",
        "restreindre",
        "restreindre",
        "restriction",
        "contraignant",
        "user de représailles",
        "représailles",
        "de représailles",
        "retard",
        "retardement",
        "réticent",
        "cornue",
        "se rétracter",
        "rétraction",
        "retranchement",
        "châtiment",
        "rétrograde",
        "vengeance",
        "renversement",
        "révocation",
        "révoquer",
        "révolte",
        "révoltant",
        "revolver",
        "dégoût",
        "rhumatisme",
        "rachitique",
        "criblé",
        "ridicule",
        "ridicule",
        "répandre",
        "fusil",
        "crevasse",
        "rigide",
        "rigidité",
        "rigueur",
        "rigoureux",
        "sonneur",
        "émeute",
        "séditieux",
        "risque",
        "risqué",
        "rivalité",
        "Rob",
        "voleur",
        "vol",
        "coquin",
        "tour",
        "pourrir",
        "pourrir",
        "rugosité",
        "NO TRANSLATION",
        "rangée",
        "chahuteur",
        "ordures",
        "décombres",
        "rue",
        "ébouriffer",
        "robuste",
        "se ruiner",
        "ruiné",
        "ruineux",
        "rumeur",
        "fuyez",
        "rupture",
        "NO TRANSLATION",
        "rouille",
        "rouillé",
        "impitoyable",
        "NO TRANSLATION",
        "sabotage",
        "sacrifices",
        "Malheureusement",
        "tristesse",
        "affaissement",
        "sève",
        "sarcasme",
        "sarcome",
        "sardonique",
        "satanique",
        "saturé",
        "sauvage",
        "sauvagerie",
        "gale",
        "échafaud",
        "scalpel",
        "écailleux",
        "scandale",
        "scandaleux",
        "maigre",
        "bouc émissaire",
        "cicatrice",
        "rare",
        "à peine",
        "rareté",
        "effrayer",
        "charognard",
        "schème",
        "schisme",
        "schizophrénie",
        "sciatique",
        "moquerie",
        "gronder",
        "réprimande",
        "brûlant",
        "mépris",
        "Scorpion",
        "scotch",
        "scélérat",
        "fléau",
        "brouiller",
        "tremblante",
        "crier",
        "en hurlant",
        "hurler",
        "vissé",
        "mêlée",
        "frotter",
        "scruter",
        "examen minutieux",
        "écume",
        "sear",
        "sécession",
        "isolé",
        "NO TRANSLATION",
        "sécrétion",
        "secret",
        "sectaire",
        "sédition",
        "séduire",
        "séduction",
        "séparer",
        "séparé",
        "s'emparer de",
        "égoïste",
        "égoïsme",
        "sénile",
        "insensé",
        "phrase",
        "séparatiste",
        "état septique",
        "septique",
        "séquestration",
        "serein",
        "serpent",
        "serviteur",
        "servir",
        "servile",
        "servitude",
        "revers",
        "rompre",
        "eaux usées",
        "égouts",
        "minable",
        "cabane",
        "manille",
        "ombragé",
        "tremblement",
        "précaire",
        "faux",
        "pagaille",
        "la honte",
        "honteux",
        "éhonté",
        "Shanghai",
        "requin",
        "briser",
        "brisé",
        "cabanon",
        "coquille",
        "rangé",
        "Naufrage",
        "merde",
        "frisson",
        "choc",
        "de mauvaise qualité",
        "tirer",
        "tournage",
        "vol à l'étalage",
        "pénurie",
        "défaut",
        "coup",
        "pousser",
        "voyant",
        "cri",
        "aigu",
        "rétrécir",
        "rétréci",
        "frémir",
        "éviter",
        "malade",
        "écœurant",
        "maladif",
        "maladie",
        "idiot",
        "NO TRANSLATION",
        "coupable",
        "sinistre",
        "pécheur",
        "pécher",
        "sirène",
        "poule mouillée",
        "sceptique",
        "vague",
        "biaisé",
        "déraper",
        "sauter",
        "escarmouche",
        "mou",
        "scories",
        "claquer",
        "calomnie",
        "diffamatoire",
        "gifler",
        "abattage",
        "abattoir",
        "abattage",
        "esclave",
        "esclavage",
        "tuer",
        "tueur",
        "neige fondue",
        "visqueux",
        "slink",
        "caleçon",
        "NO TRANSLATION",
        "négligé",
        "la paresse",
        "affamé",
        "bourbier",
        "la lenteur",
        "boue",
        "limace",
        "paresseux",
        "taudis",
        "marasme",
        "liaison",
        "neige fondante",
        "salope",
        "sournois",
        "claque",
        "petit",
        "fracasser",
        "brisé",
        "poignée",
        "odeur",
        "odeur",
        "petit sourire satisfait",
        "frapper",
        "fumeur",
        "étouffer",
        "tache",
        "suffisant",
        "passer en contrebande",
        "contrebandier",
        "contrebande",
        "cochonneries",
        "accroc",
        "des chicots",
        "serpent",
        "piège",
        "gronder",
        "harceler",
        "se faufiler",
        "faufiler",
        "ricanement",
        "éternuement",
        "sarcastique",
        "snob",
        "tremper",
        "NO TRANSLATION",
        "socialiste",
        "sol",
        "souillé",
        "somatique",
        "sombre",
        "suie",
        "sorcellerie",
        "sordide",
        "endolori",
        "grandement",
        "douleur",
        "chagrin",
        "douloureux",
        "NO TRANSLATION",
        "inhumain",
        "âme sœur",
        "acide",
        "fesser",
        "spasme",
        "prise de bec",
        "lance",
        "grain",
        "spectre",
        "spectral",
        "spéculation",
        "dépensé",
        "vieille fille",
        "dépit",
        "malveillant",
        "éclat",
        "Divisé",
        "scission",
        "gâcher",
        "becquet",
        "parlait",
        "éponge",
        "effrayer",
        "entorse",
        "fête",
        "lutin",
        "faux",
        "bourrasque",
        "squatter",
        "délicat",
        "écraser",
        "se tortiller",
        "poignarder",
        "échelonnement",
        "stagnant",
        "tache",
        "vicié",
        "tige",
        "impasse",
        "arrêt",
        "regarder",
        "rigide",
        "surprendre",
        "famine",
        "affamé",
        "affamé",
        "Stationnaire",
        "portée",
        "voler",
        "vol",
        "furtif",
        "stéréotype",
        "stéréotypé",
        "stérile",
        "stérilité",
        "arrière",
        "rigide",
        "rigidité",
        "étouffer",
        "étouffé",
        "stigmate",
        "mort-né",
        "piquer",
        "piqûre",
        "avare",
        "puanteur",
        "puant",
        "besogne assignée",
        "stocks",
        "volé",
        "pierre",
        "lapidé",
        "selles",
        "arrêt",
        "orage",
        "orageux",
        "tendu",
        "détroits",
        "échoué",
        "étranger",
        "étrangler",
        "égarer",
        "stress",
        "conflit",
        "la grève",
        "bande",
        "Bande",
        "dépouillé",
        "accident vasculaire cérébral",
        "lutte",
        "se pavaner",
        "bouché",
        "trébucher",
        "étourdi",
        "rabougri",
        "stupide",
        "stupidité",
        "stupeur",
        "porcherie",
        "maîtriser",
        "assujettir",
        "soumis",
        "sujétion",
        "assujettissement",
        "subalterne",
        "assignation",
        "affaissement",
        "subvention",
        "subsister",
        "soustraire",
        "subversion",
        "subversif",
        "subvertir",
        "succomber",
        "sucer",
        "ventouse",
        "poursuivre en justice",
        "souffrir",
        "victime",
        "Souffrance",
        "étouffant",
        "suffocation",
        "suicidaire",
        "suicide",
        "renfrogné",
        "assignation",
        "coulé",
        "superficiel",
        "superflu",
        "superstitieux",
        "réprimer",
        "suppression",
        "surtaxe",
        "bourru",
        "abandon",
        "se rendre",
        "sensible",
        "suspect",
        "suspension",
        "soupçon",
        "méfiant",
        "écouvillon",
        "marais",
        "marécageux",
        "svastika",
        "gonflement",
        "lampée",
        "porc",
        "gonflé",
        "symptôme",
        "syncope",
        "tabou",
        "entacher",
        "NO TRANSLATION",
        "emmêlé",
        "lenteur",
        "tardif",
        "tarif",
        "ternir",
        "goudronneux",
        "insipide",
        "raillerie",
        "impôt",
        "taquiner",
        "taquineries",
        "fastidieux",
        "NO TRANSLATION",
        "tempête",
        "tentation",
        "immeuble",
        "Terminal",
        "Résiliation",
        "termite",
        "terrible",
        "la terreur",
        "terrorisme",
        "terroriste",
        "terroriser",
        "tétanos",
        "attache",
        "vol",
        "théisme",
        "théocratique",
        "voleur",
        "assoiffé",
        "épine",
        "épineux",
        "irréfléchi",
        "débattre",
        "menace",
        "menacer",
        "menaçant",
        "battre",
        "palpiter",
        "étrangler",
        "voyou",
        "cogner",
        "tonner",
        "contrecarrer",
        "tiff",
        "timide",
        "timidité",
        "pompette",
        "tirade",
        "fatigué",
        "fatigue",
        "fatigant",
        "mésange",
        "crapaud",
        "le tabac",
        "toilette",
        "rets",
        "tolérer",
        "mal aux dents",
        "tourmenter",
        "déchiré",
        "torpille",
        "torride",
        "délit",
        "déloyal",
        "torture",
        "touché",
        "suceptible",
        "dure",
        "toxique",
        "toxine",
        "la tragédie",
        "tragique",
        "traitre",
        "tramp",
        "transe",
        "transgression",
        "ornements",
        "pièges",
        "poubelle",
        "trash",
        "traumatique",
        "NO TRANSLATION",
        "travestir",
        "perfide",
        "traîtrise",
        "trahison",
        "tremblant",
        "tremblement",
        "inquiétude",
        "intrusion",
        "tribulations",
        "tribunal",
        "tour",
        "tromperie",
        "bagatelle",
        "trébucher",
        "troll",
        "gênant",
        "trompette",
        "chute",
        "tumeur",
        "tumeur",
        "tumulte",
        "tumultueux",
        "turbulence",
        "turbulent",
        "la tourmente",
        "tic",
        "typhon",
        "tyrannique",
        "tyrannie",
        "tyran",
        "la laideur",
        "laid",
        "ulcère",
        "ultérieur",
        "ultimatum",
        "incapable",
        "inacceptable",
        "inexplicable",
        "non approuvé",
        "libre",
        "inaccessible",
        "peu attrayant",
        "non autorisé",
        "inévitable",
        "ignorant",
        "insupportable",
        "incrédulité",
        "incroyable",
        "à naître",
        "étrange",
        "indifférent",
        "incertain",
        "non modifiable",
        "impur",
        "inconfortable",
        "déraisonnable",
        "inconscient",
        "inconstitutionnel",
        "incontrôlable",
        "incontrôlé",
        "indécis",
        "miné",
        "sous-payés",
        "trop petit",
        "indésirable",
        "indésirable",
        "annuler",
        "malaise",
        "inquiet",
        "sans instruction",
        "sans emploi",
        "inégal",
        "inégal",
        "inexpliqué",
        "injuste",
        "injustice",
        "infidèle",
        "défavorable",
        "inachevé",
        "impitoyable",
        "malheureux",
        "hostile",
        "insatisfait",
        "non meublé",
        "impie",
        "ingrat",
        "le malheur",
        "malheureux",
        "mauvais pour la santé",
        "impie",
        "sans importance",
        "pas impressionné",
        "non amélioré",
        "mal informé",
        "non initié",
        "sans inspiration",
        "inintelligible",
        "involontairement",
        "indifférent",
        "inintéressant",
        "injuste",
        "injustifiable",
        "injustifié",
        "méchant",
        "inconnu",
        "illicite",
        "sans licence",
        "malchanceux",
        "ingérable",
        "non naturel",
        "non officiel",
        "non payé",
        "désagréable",
        "impopulaire",
        "imprévisible",
        "non préparé",
        "improductif",
        "peu rentable",
        "non protégé",
        "non publié",
        "non fiable",
        "non partagé",
        "indiscipliné",
        "peu sûr",
        "insatisfaisant",
        "insatisfait",
        "peu recommandable",
        "sans scrupules",
        "instable",
        "disgracieux",
        "simple",
        "indicible",
        "instable",
        "infructueux",
        "inapproprié",
        "méconnu",
        "non pris en charge",
        "insoutenable",
        "antipathique",
        "sauvage",
        "intenable",
        "impensable",
        "désordonné",
        "prématuré",
        "sans titre",
        "inconnu",
        "fâcheux",
        "non formé",
        "faux",
        "indigne de confiance",
        "injustifié",
        "non lavé",
        "importun",
        "indisposé",
        "réticence",
        "imprudent",
        "involontaire",
        "indigne",
        "inflexible",
        "bouleversement",
        "soulèvement",
        "tumulte",
        "dérangé",
        "oursin",
        "urgent",
        "inutile",
        "usurper",
        "usurpé",
        "usure",
        "poste vacant",
        "vide",
        "vague",
        "imprécision",
        "vainement",
        "vampire",
        "disparu",
        "vanité",
        "varicelle",
        "variqueux",
        "végétatif",
        "véhément",
        "Vendetta",
        "vengeance",
        "vengeur",
        "venin",
        "venimeux",
        "verbosité",
        "bord",
        "vermine",
        "contre",
        "vertige",
        "veto",
        "vice",
        "vicieux",
        "victime",
        "victimisé",
        "scélérat",
        "infâme",
        "vindicatif",
        "violation",
        "la violence",
        "violent",
        "violemment",
        "vipère",
        "virulence",
        "virus",
        "visitation",
        "renarde",
        "volatilité",
        "volcan",
        "vomissement",
        "vaudou",
        "vulgaire",
        "la vulgarité",
        "vulnérabilité",
        "vautour",
        "gaufre",
        "lamenter",
        "attendez",
        "se vautrer",
        "NO TRANSLATION",
        "décliner",
        "vouloir",
        "guerre",
        "directeur",
        "ware",
        "guerre",
        "guerrier",
        "prévenir",
        "chaîne",
        "voilé",
        "verrue",
        "déchets",
        "perdu",
        "gaspilleur",
        "gaspillage",
        "aqueux",
        "vaciller",
        "affaibli",
        "faiblement",
        "la faiblesse",
        "porter",
        "fatigué",
        "lassitude",
        "se lasser",
        "mauvaises herbes",
        "pleurer",
        "bizarre",
        "bizarre",
        "NO TRANSLATION",
        "jeune fille",
        "battre",
        "caprice",
        "gémissement",
        "fouet",
        "tourbillon",
        "whisky",
        "putain",
        "méchant",
        "la méchanceté",
        "sauvage",
        "chat sauvage",
        "incendies",
        "délibéré",
        "mauviette",
        "mauviette",
        "grimacer",
        "sorcière",
        "la sorcellerie",
        "se désister",
        "flétrir",
        "flétri",
        "malheur",
        "triste",
        "tristement",
        "mots",
        "ver",
        "usé",
        "inquiet",
        "inquiéter",
        "inquiétant",
        "pire",
        "détérioration",
        "sans valeur",
        "blessure",
        "querelles",
        "colère",
        "assouvir",
        "épave",
        "détruit",
        "clé",
        "lutte",
        "misérable",
        "misérable",
        "faux",
        "méfait",
        "injustifié",
        "à tort",
        "forgé",
        "tordu",
        "xénophobie",
        "bâillement",
        "bâillement",
        "hurler",
        "jaunes",
        "japper",
        "Zip *: français",
    ]
)

_ambivalent = set(
    [
        "abondance",
        "armé",
        "baume",
        "se vanter",
        "bruyant",
        "rat de bibliothèque",
        "mâle",
        "célébrité",
        "charmé",
        "contournement",
        "complicité",
        "avouer",
        "ruse",
        "dépendant",
        "diverse",
        "dominer",
        "interminable",
        "imposer",
        "érotique",
        "échapper",
        "sentiment",
        "flirter",
        "saluer",
        "hédonisme",
        "le plus élevé",
        "humble",
        "immédiatement",
        "immeuble",
        "le revenu",
        "infiltration",
        "influence",
        "intense",
        "interminable",
        "intervention",
        "dentelle",
        "libéral",
        "Seigneur",
        "maternel",
        "sage-femme",
        "mère",
        "agresser",
        "notoriété",
        "omnipotence",
        "explosion",
        "exceptionnel",
        "parade",
        "paraphrase",
        "pétrole",
        "présentation",
        "prodigue",
        "citation",
        "délirer",
        "régressif",
        "raviver",
        "restes",
        "retraite",
        "relancer",
        "révolution",
        "épouvantail",
        "isolement",
        "sensuel",
        "spectacle",
        "colonne vertébrale",
        "sterling",
        "succulent",
        "superstition",
        "suprématie",
        "entourer",
        "synonyme",
        "alléchant",
        "les adolescents",
        "traiter",
        "invaincu",
        "débridé",
        "inattendu",
        "inimaginable",
        "délier",
        "montée",
        "vote",
        "poids",
        "aspiration",
    ]
)



_antonyms = {
    "habilidade": "incapacidade",
    "anormal": "normal",
    "abolir": "estabelecer",
    "ausência": "presença",
    "ausente": "presente",
    "futuro": "passado",
    "absoluto": "relativo",
    "abster-se": "consumir",
    "abstrato": "concreto",
    "abundância": "escassez",
    "abundante": "escasso",
    "aceitar": "rejeitar",
    "admitem": "negar",
    "aceitável": "inaceitável",
    "aceitação": "rejeição",
    "acessível": "inacessível",
    "preciso": "impreciso",
    "reconhecido": "não reconhecido",
    "conhecido": "desconhecido",
    "aja": "refrão",
    "açao": "inação",
    "ativo": "quieto",
    "existente": "inexistente",
    "barulhento": "quieto",
    "atividade": "inatividade",
    "real": "irreal",
    "adicionar": "subtrair",
    "adição": "subtração",
    "adequado": "inadequado",
    "adjetivo": "substantivo",
    "admissível": "inadmissível",
    "adulto": "juvenil",
    "avançar": "recuar",
    "adiante": "costas",
    "frente": "traseira",
    "virar": "costas",
    "vantagem": "desvantagem",
    "afirmação": "perder",
    "afirmativo": "negativo",
    "neutro": "feminino",
    "a popa": "fore",
    "era": "rejuvenescer",
    "idade": "jovem",
    "agitação": "calma",
    "aceita": "discordar",
    "agradável": "desagradável",
    "acordo": "desacordo",
    "alterado": "inalterado",
    "alternar": "oposto",
    "amador": "profissional",
    "ambíguo": "sem ambiguidade",
    "amigável": "hostil",
    "amigáveis": "hostil",
    "anfíbio": "terrestre",
    "anal": "oral",
    "análogo": "homóloga",
    "análise": "síntese",
    "analítico": "sintético",
    "antepassado": "descendente",
    "angular": "arredondado",
    "animar": "inanimado",
    "responda": "questão",
    "antagônico": "sinérgico",
    "antecedente": "subseqüente",
    "anterior": "posterior",
    "antisséptico": "séptico",
    "aparência": "desaparecimento",
    "apreciação": "depreciação",
    "aprovação": "desaprovação",
    "aprovar": "desaprovar",
    "aquático": "anfíbio",
    "terrestre": "celestial",
    "aquoso": "ígneo",
    "braço": "desarmar",
    "armado": "desarmado",
    "chegar": "sair",
    "subir": "conjunto",
    "subida": "descida",
    "adormecido": "acordado",
    "concordância": "dissidência",
    "assimetria": "simetria",
    "ateísmo": "teísmo",
    "anexar": "desanexar",
    "ataque": "defender",
    "processar": "defender",
    "atenção": "falta de atenção",
    "atração": "repulsão",
    "audível": "inaudível",
    "aumento": "diminuição",
    "tia": "tio",
    "autorizado": "não autorizado",
    "automático": "manual",
    "evitar": "enfrentar",
    "acordado": "adormecido",
    "costas": "virar",
    "recuar": "avançar",
    "traseira": "cabeça",
    "fundo": "primeiro plano",
    "para trás": "frente",
    "marcha ré": "anverso",
    "mau": "boa",
    "mal": "boa",
    "maldade": "bondade",
    "equilibrado": "desequilibrado",
    "urso": "touro",
    "bonita": "feio",
    "beleza": "feiúra",
    "início": "fim",
    "começando": "meio",
    "cedo": "atrasado",
    "crença": "incredulidade",
    "dobrar": "endireitar",
    "benigno": "maligno",
    "grande": "pequeno",
    "ampla": "pequeno",
    "nascimento": "morte",
    "bissexual": "homossexual",
    "preto": "branco",
    "abençoe": "maldição",
    "abençoado": "amaldiçoado",
    "sem sangue": "sangrento",
    "sangrento": "sem sangue",
    "borrão": "foco",
    "ferver": "congelar",
    "negrito": "tímido",
    "ousadia": "timidez",
    "pedir emprestado": "emprestar",
    "mutuário": "emprestador",
    "inferior": "superior",
    "limite": "não consolidado",
    "garoto": "menina",
    "boicote": "patrocinar",
    "pausa": "reparar",
    "quebrável": "inquebrável",
    "iluminar": "escurecer",
    "aliviar": "escurecer",
    "partido": "inteiro",
    "irmão": "irmã",
    "touro": "urso",
    "ocupado": "desocupado",
    "trabalhos": "ocioso",
    "comprar": "vender",
    "calma": "agitação",
    "capaz": "incapaz",
    "capacidade": "incapacidade",
    "dinheiro": "crédito",
    "débito": "crédito",
    "centro": "esquerda",
    "cerebral": "emocional",
    "certeza": "incerteza",
    "mudança": "fique",
    "partida": "fique",
    "mover": "fique",
    "mutável": "imutável",
    "mudou": "inalterado",
    "carregar": "descarga",
    "alista": "descarga",
    "barato": "caro",
    "torcer": "reclamar",
    "alegre": "triste",
    "criança": "pai",
    "civil": "militares",
    "clareza": "opacidade",
    "proeminência": "obscuridade",
    "transparência": "opacidade",
    "limpar \ limpo": "imundo",
    "clero": "leigos",
    "clérigo": "leigo",
    "fechar": "aberto",
    "fechadas": "aberto",
    "proximidade": "abertura",
    "costeiro": "interior",
    "coerente": "incoerente",
    "frio": "quente",
    "colateral": "linear",
    "comédia": "tragédia",
    "conforto": "desconforto",
    "comum": "extraordinário",
    "compatível": "desafiante",
    "competência": "incompetência",
    "competente": "incompetente",
    "concorrência": "cooperação",
    "reclamar": "torcer",
    "completude": "incompletude",
    "complexo": "simples",
    "composto": "simples",
    "complicar": "simplificar",
    "côncavo": "convexo",
    "presunção": "humildade",
    "orgulho": "humildade",
    "concentração": "distribuição",
    "concêntrico": "excêntrico",
    "concepção": "equívoco",
    "preocupado": "despreocupado",
    "concreto": "abstrato",
    "confirmado": "não confirmado",
    "enfrentar": "evitar",
    "conjuntivo": "disjuntivo",
    "conectar": "desconectar",
    "conectado": "desconectado",
    "consciência": "inconsciência",
    "conservador": "liberal",
    "conservar": "desperdício",
    "atencioso": "inconsiderado",
    "consistência": "inconsistência",
    "consoante": "vogal",
    "conspícuo": "discreto",
    "constitucional": "inconstitucional",
    "consumir": "abster-se",
    "conteúdo": "descontentamento",
    "contínuo": "descontínuo",
    "continuação": "descontinuação",
    "continuar": "descontinuar",
    "continuidade": "descontinuidade",
    "contrato": "expandir",
    "contratado": "expandido",
    "contração": "expansão",
    "conveniente": "inconveniente",
    "convencional": "não convencional",
    "convergem": "divergir",
    "convergência": "divergência",
    "convergente": "divergente",
    "convexo": "côncavo",
    "convencido": "não convencido",
    "legal": "ilegal",
    "cooperação": "concorrência",
    "cosmopolita": "provincial",
    "coragem": "covardia",
    "tampa": "descobrir",
    "encoberta": "abertos",
    "covardia": "coragem",
    "crédito": "débito",
    "credor": "devedor",
    "criticar": "elogio",
    "chorar": "rir",
    "curável": "incurável",
    "maldição": "abençoe",
    "amaldiçoado": "abençoado",
    "curvado": "direto",
    "cortar": "sem cortes",
    "perigo": "segurança",
    "perigoso": "seguro",
    "sombrio": "luz",
    "escurecer": "aliviar",
    "trevas": "leveza",
    "peso": "leveza",
    "filha": "filho",
    "dia": "noite",
    "surdo": "audição",
    "morte": "nascimento",
    "devedor": "credor",
    "decência": "indecência",
    "decente": "indecente",
    "decíduo": "evergreen",
    "decisão": "indecisão",
    "decisivo": "indeciso",
    "declínio": "melhoria",
    "diminuir": "aumentar",
    "diminuiu": "aumentou",
    "decremento": "incremento",
    "derrota": "vitória",
    "defender": "processar",
    "réu": "demandante",
    "defesa": "processo",
    "defensiva": "ofensiva",
    "desafiante": "compatível",
    "déficit": "conduzir",
    "definiram": "indefinido",
    "deflação": "inflação",
    "demora": "pressa",
    "demorar": "pressa",
    "exigem": "fornecem",
    "negar": "admitem",
    "rejeitar": "aceitar",
    "dependente": "independente",
    "depósito": "retirar o",
    "depreciação": "apreciação",
    "deprimente": "alegre",
    "descer": "subir",
    "descendente": "antepassado",
    "descida": "subida",
    "descritivo": "prescritivo",
    "desejável": "indesejável",
    "desespero": "esperança",
    "desesperado": "esperança",
    "destruído": "preservado",
    "desanexar": "anexar",
    "devolução": "evolução",
    "diferem": "igual",
    "desigual": "equitativo",
    "diferença": "semelhança",
    "difícil": "fácil",
    "desconfortável": "fácil",
    "dificuldade": "facilidade",
    "diligente": "negligente",
    "diluição": "concentração",
    "distribuição": "concentração",
    "diminuição": "aumento",
    "sujo": "limpar \ limpo",
    "imundo": "limpar \ limpo",
    "desativar": "habilitar",
    "desvantagem": "vantagem",
    "discordar": "aceita",
    "desagradável": "salgados",
    "desacordo": "acordo",
    "desaparecimento": "aparência",
    "desaprovação": "aprovação",
    "desaprovar": "aprovar",
    "desarmar": "braço",
    "descarga": "alista",
    "renunciar": "afirmação",
    "perder": "encontrar",
    "desconforto": "conforto",
    "desconectar": "conectar",
    "descontentamento": "conteúdo",
    "descontinuação": "continuação",
    "descontinuar": "continuar",
    "descontinuidade": "continuidade",
    "descontínuo": "contínuo",
    "desencorajar": "encorajar",
    "desânimo": "encorajamento",
    "desengatar": "se empenhar",
    "desonesto": "honesto",
    "desonestidade": "honestidade",
    "desonra": "honra",
    "desinfecte": "infectar",
    "desintegrar": "integrar",
    "disjuntivo": "conjuntivo",
    "não gosta": "gosto",
    "desalojar": "apresentar",
    "desobediência": "obediência",
    "desobediente": "obediente",
    "desobedecer": "obedecer",
    "desordem": "ordem",
    "desordenado": "ordenadamente",
    "desorganizado": "organizado",
    "desagradado": "satisfeito",
    "refutar": "provar",
    "desqualificar": "qualificar",
    "infeliz": "feliz",
    "descrédito": "reputação",
    "desrespeito": "respeito",
    "desrespeitoso": "respeitoso",
    "insatisfação": "satisfação",
    "dissidência": "concordância",
    "desserviço": "serviço",
    "diferente": "semelhante",
    "dissonância": "harmonia",
    "dissuadir": "persuadir",
    "distal": "proximal",
    "distante": "fechar",
    "aberto": "fechar",
    "distinguível": "indistinguível",
    "desconfiança": "confiar em",
    "diurno": "noturno",
    "divergir": "convergem",
    "divergência": "convergência",
    "divergente": "convergente",
    "dividir": "unir",
    "sozinho": "multiplicar",
    "dividido": "unidos",
    "divisível": "indivisível",
    "doméstica": "estrangeiro",
    "nativo": "estrangeiro",
    "dominante": "subordinar",
    "dormente": "ativo",
    "extinto": "existente",
    "inativo": "ativo",
    "passiva": "ativo",
    "quieto": "barulhento",
    "duplo": "solteiro",
    "múltiplo": "solteiro",
    "pomba": "falcão",
    "dramático": "letra",
    "seco": "molhado",
    "azedar": "adoçar",
    "vencimento": "indevida",
    "maçante": "aguçar",
    "aplainar": "aguçar",
    "morrendo": "nascente",
    "facilidade": "dificuldade",
    "fácil": "desconfortável",
    "ebb": "maré",
    "excêntrico": "concêntrico",
    "educado": "indelicado",
    "eficaz": "ineficaz",
    "eficiência": "ineficiência",
    "eficiente": "ineficiente",
    "saída": "entrada",
    "elástico": "inelástica",
    "elegíveis": "inelegível",
    "emocional": "cerebral",
    "empírico": "teórico",
    "vazio": "cheio",
    "fino": "engrossar",
    "habilitar": "desativar",
    "encorajar": "desencorajar",
    "encorajamento": "desânimo",
    "fim": "começando",
    "final": "próximo",
    "meio": "cedo",
    "endêmico": "cosmopolita",
    "provincial": "cosmopolita",
    "energético": "letárgico",
    "reforçar": "isentar",
    "se empenhar": "desengatar",
    "apreciar": "sofra",
    "entrar": "saída",
    "igual": "desigual",
    "igualdade": "desigualdade",
    "equatorial": "polar",
    "equitativo": "desigual",
    "equívoco": "concepção",
    "apagar": "registro",
    "estabelecer": "abolir",
    "agitado": "sem intercorrências",
    "evergreen": "decíduo",
    "evolução": "devolução",
    "exclusão": "inclusão",
    "isentar": "reforçar",
    "exalar": "inalar",
    "saída": "entrar",
    "expandir": "contrato",
    "expandido": "contratado",
    "expansão": "contração",
    "esperado": "inesperado",
    "caro": "barato",
    "com experiência": "inexperiente",
    "exportar": "importar",
    "expressar": "local",
    "geral": "específico",
    "nacional": "internacional",
    "extensão": "flexão",
    "exterior": "interior",
    "externo": "interno",
    "externamente": "internamente",
    "extinguir": "inflamar",
    "extramuros": "intramural",
    "extraordinário": "comum",
    "extrínseco": "intrínseco",
    "falhando": "passagem",
    "corrida": "parado",
    "falha": "sucesso",
    "justo": "injusto",
    "fiel": "infiel",
    "cair": "subir",
    "conjunto": "subir",
    "falível": "infalível",
    "queda": "aumentar",
    "falsidade": "verdade",
    "fama": "infâmia",
    "familiar": "desconhecido",
    "chique": "avião",
    "gordo": "fino",
    "cheio": "vazio",
    "grosso": "fino",
    "engrossar": "fino",
    "pai": "criança",
    "fauna": "flora",
    "favorável": "desfavorável",
    "federal": "unitário",
    "fêmea": "masculino",
    "feminino": "neutro",
    "feminilidade": "masculinidade",
    "fertil": "estéril",
    "fidelidade": "infidelidade",
    "figura": "chão",
    "preencher": "vazio",
    "encontrar": "perder",
    "terminar": "começar",
    "pare": "começar",
    "finito": "infinito",
    "fogo": "contratar",
    "flexão": "extensão",
    "flutuador": "pia",
    "fonte": "pia",
    "flora": "fauna",
    "foco": "borrão",
    "inimigo": "amigos",
    "dobra": "desdobrar",
    "segue": "preceder",
    "ter sucesso": "preceder",
    "seguidor": "líder",
    "loucura": "sabedoria",
    "insensato": "sensato",
    "pé": "cabeça",
    "rabo": "cabeça",
    "proibido": "permitir",
    "fore": "a popa",
    "primeiro plano": "fundo",
    "estrangeiro": "nativo",
    "esqueço": "lembrar",
    "perdoando": "implacável",
    "formalismo": "imitação",
    "afortunado": "infeliz",
    "anverso": "marcha ré",
    "falta": "justo",
    "injusto": "justo",
    "encontrado": "perdido",
    "fraterno": "idêntico",
    "congelar": "ferver",
    "freqüente": "infreqüente",
    "freqüentemente": "raramente",
    "amigos": "inimigo",
    "cabeça": "rabo",
    "plenitude": "vazio",
    "funcional": "orgânico",
    "inorgânico": "orgânico",
    "ganho": "perda",
    "gasoso": "sólido",
    "oco": "sólido",
    "reunir": "espalhar",
    "generalidade": "particularidade",
    "generoso": "mesquinho",
    "menina": "garoto",
    "boa": "mal",
    "bondade": "maldade",
    "gradual": "de repente",
    "grato": "ingrato",
    "maior": "menor",
    "verde": "maduro",
    "bruto": "líquido",
    "chão": "figura",
    "culpa": "inocência",
    "culpado": "inocente",
    "alegremente": "infelizmente",
    "felicidade": "infelicidade",
    "feliz": "infeliz",
    "dureza": "suavidade",
    "intensidade": "suavidade",
    "nitidez": "suavidade",
    "harmonia": "dissonância",
    "ódio": "amor",
    "odioso": "adorável",
    "falcão": "pomba",
    "saudável": "pouco saudável",
    "audição": "surdo",
    "calor": "legal",
    "celestial": "terrestre",
    "heterogeneidade": "homogeneidade",
    "ocultar": "exposição",
    "contratar": "fogo",
    "acertar": "senhorita",
    "piedosos": "impiedade",
    "homogeneidade": "heterogeneidade",
    "homóloga": "análogo",
    "homossexual": "bissexual",
    "honesto": "desonesto",
    "honestidade": "desonestidade",
    "honra": "desonra",
    "esperança": "desespero",
    "esperançoso": "sem esperança",
    "sem esperança": "esperançoso",
    "horizontal": "vertical",
    "hostil": "amigáveis",
    "quente": "frio",
    "humilde": "orgulhoso",
    "humildade": "orgulho",
    "com fome": "com sede",
    "idêntico": "fraterno",
    "ocioso": "trabalhos",
    "ígneo": "aquoso",
    "inflamar": "extinguir",
    "ignorar": "aviso prévio",
    "ilegal": "legal",
    "ilegalidade": "legalidade",
    "ilegível": "legível",
    "ilógico": "lógico",
    "imitação": "formalismo",
    "imaterial": "material",
    "imaturidade": "maturidade",
    "imensurável": "mensurável",
    "imoral": "moral",
    "imoralidade": "moralidade",
    "imortal": "mortal",
    "imortalidade": "mortalidade",
    "imutável": "mutável",
    "imparcialidade": "parcialidade",
    "intransitável": "passável",
    "impaciência": "paciência",
    "impaciente": "paciente",
    "imperceptível": "perceptível",
    "imperfeição": "perfeição",
    "impermeável": "permeável",
    "inadmissível": "admissível",
    "impessoal": "pessoal",
    "indelicado": "educado",
    "importar": "exportar",
    "importante": "sem importância",
    "impossibilidade": "possibilidade",
    "impotente": "poderoso",
    "improvável": "provável",
    "melhorado": "não melhorado",
    "melhoria": "declínio",
    "imprudente": "cauteloso",
    "impureza": "pureza",
    "incapacidade": "capacidade",
    "inacessível": "acessível",
    "impreciso": "preciso",
    "inação": "açao",
    "inatividade": "atividade",
    "inadequado": "adequado",
    "inanimado": "animar",
    "falta de atenção": "atenção",
    "inaudível": "audível",
    "incapaz": "capaz",
    "inclinado": "horizontal",
    "vertical": "horizontal",
    "inclusão": "exclusão",
    "incoerente": "coerente",
    "incompatível": "compatível",
    "incompetência": "competência",
    "incompetente": "competente",
    "incompletude": "completude",
    "inconsiderado": "atencioso",
    "inconsistência": "consistência",
    "discreto": "conspícuo",
    "inconveniente": "conveniente",
    "aumentar": "diminuir",
    "aumentou": "diminuiu",
    "incremento": "decremento",
    "incurável": "curável",
    "indecência": "decência",
    "indecente": "decente",
    "indecisão": "decisão",
    "indeciso": "decisivo",
    "independente": "dependente",
    "indistinguível": "distinguível",
    "indivisível": "divisível",
    "interior": "exterior",
    "ineficaz": "eficaz",
    "ineficiência": "eficiência",
    "ineficiente": "eficiente",
    "inelástica": "elástico",
    "inelegível": "elegíveis",
    "desigualdade": "igualdade",
    "inexperiente": "com experiência",
    "infalível": "falível",
    "infâmia": "fama",
    "infectar": "desinfecte",
    "inferioridade": "superioridade",
    "infidelidade": "fidelidade",
    "infinito": "finito",
    "inflação": "deflação",
    "informado": "desinformado",
    "infreqüente": "freqüente",
    "raramente": "freqüentemente",
    "entrada": "saída",
    "habitado": "desabafado",
    "inalar": "exalar",
    "injustiça": "justiça",
    "inocência": "culpa",
    "inocente": "culpado",
    "inócuo": "nocivo",
    "inoperante": "operativo",
    "insano": "sã",
    "insanidade": "sanidade",
    "insegurança": "segurança",
    "insignificância": "significado",
    "insignificante": "significativo",
    "insolúvel": "solúvel",
    "insolvência": "solvência",
    "insolvente": "solvente",
    "instabilidade": "estabilidade",
    "instrumental": "vocal",
    "insuficiência": "suficiência",
    "insuficiente": "suficiente",
    "insuficientemente": "suficientemente",
    "integrar": "desintegrar",
    "integração": "separação",
    "inteligência": "estupidez",
    "inteligível": "ininteligível",
    "pretendido": "não intencional",
    "intencionalmente": "sem querer",
    "interessado": "desinteressado",
    "interessante": "desinteressante",
    "intermediário": "terminal",
    "interno": "externo",
    "internamente": "externamente",
    "internacional": "nacional",
    "local": "geral",
    "intolerância": "tolerância",
    "intolerante": "tolerante",
    "intratável": "tratável",
    "intramural": "extramuros",
    "intrínseco": "extrínseco",
    "invisibilidade": "visibilidade",
    "invisível": "visível",
    "involuntário": "voluntário",
    "irracional": "racional",
    "irregular": "regular",
    "irregularidade": "regularidade",
    "irrelevante": "relevante",
    "irresponsável": "responsável",
    "irreverente": "reverente",
    "questão": "responda",
    "junta": "separado",
    "alegria": "tristeza",
    "júnior": "senior",
    "justiça": "injustiça",
    "juvenil": "adulto",
    "kern": "kern",
    "tipo": "desagradável",
    "rei": "rainha",
    "leigos": "clero",
    "atrasado": "cedo",
    "rir": "chorar",
    "laxista": "tenso",
    "relaxado": "tenso",
    "leigo": "clérigo",
    "conduzir": "déficit",
    "líder": "seguidor",
    "sair": "chegar",
    "esquerda": "centro",
    "legalidade": "ilegalidade",
    "legalizar": "bandido",
    "legível": "ilegível",
    "emprestar": "pedir emprestado",
    "emprestador": "mutuário",
    "alongar": "encurtar",
    "menor": "principal",
    "letárgico": "energético",
    "nível": "levantar",
    "mais baixo": "levantar",
    "liberal": "conservador",
    "mentira": "ficar de pé",
    "produção": "ficar de pé",
    "luz": "sombrio",
    "leveza": "peso",
    "gosto": "não gosta",
    "limitado": "ilimitado",
    "linear": "colateral",
    "líquido": "bruto",
    "sólido": "oco",
    "específico": "geral",
    "localização": "estúdio",
    "bloqueio": "desbloquear",
    "apresentar": "desalojar",
    "lógico": "ilógico",
    "longo": "curto",
    "alta": "curto",
    "afrouxar": "endurecer",
    "perda": "ganho",
    "perdido": "encontrado",
    "adorável": "odioso",
    "amor": "ódio",
    "por sorte": "azarado",
    "letra": "dramático",
    "principal": "menor",
    "maioria": "minoria",
    "faço": "pausa",
    "reparar": "pausa",
    "masculino": "feminino",
    "maligno": "benigno",
    "manual": "automático",
    "marcado": "sem marca",
    "casado": "solteiro",
    "masculinidade": "feminilidade",
    "mascarar": "desmascarar",
    "material": "imaterial",
    "materno": "paterno",
    "maturidade": "imaturidade",
    "máximo": "mínimo",
    "mensurável": "imensurável",
    "mental": "fisica",
    "misericordioso": "implacável",
    "implacável": "perdoando",
    "militares": "civil",
    "mente": "esqueço",
    "lembrar": "esqueço",
    "mínimo": "máximo",
    "minoria": "maioria",
    "senhorita": "acertar",
    "molar": "molecular",
    "molecular": "molar",
    "moral": "imoral",
    "moralidade": "imoralidade",
    "mortal": "imortal",
    "mortalidade": "imortalidade",
    "mãe": "pai",
    "multiplicar": "sozinho",
    "unir": "dividir",
    "nadir": "zênite",
    "limitar": "ampliar",
    "nascente": "morrendo",
    "negativo": "neutro",
    "negligente": "diligente",
    "sobrinho": "sobrinha",
    "sobrinha": "sobrinho",
    "noite": "dia",
    "noturno": "diurno",
    "nominal": "real",
    "irreal": "real",
    "inexistente": "existente",
    "normal": "anormal",
    "aviso prévio": "ignorar",
    "nocivo": "inócuo",
    "numérico": "verbal",
    "obediência": "desobediência",
    "obediente": "desobediente",
    "obedecer": "desobedecer",
    "objetivo": "subjetivo",
    "obrigatório": "opcional",
    "oblíquo": "perpendicular",
    "obscuridade": "proeminência",
    "opacidade": "transparência",
    "ofensa": "defesa",
    "processo": "defesa",
    "ofensiva": "defensiva",
    "oficial": "não oficial",
    "abertura": "proximidade",
    "operativo": "inoperante",
    "opôs-se": "sem oposição",
    "oposto": "alternar",
    "otimismo": "pessimismo",
    "otimista": "pessimista",
    "opcional": "obrigatório",
    "oral": "anal",
    "ordem": "desordem",
    "ordenadamente": "desordenado",
    "orgânico": "inorgânico",
    "organizado": "desorganizado",
    "ortodoxo": "pouco ortodoxo",
    "ao ar livre": "interior",
    "bandido": "legalizar",
    "superestimar": "subestimar",
    "a sobrecarga": "superfície",
    "abertos": "encoberta",
    "pacote": "descompactar",
    "doloroso": "sem dor",
    "sem dor": "doloroso",
    "paralelo": "oblíquo",
    "perpendicular": "oblíquo",
    "parcialidade": "imparcialidade",
    "particularidade": "generalidade",
    "parcialmente": "completamente",
    "passável": "intransitável",
    "passagem": "corrida",
    "parado": "corrida",
    "passado": "futuro",
    "presente": "ausente",
    "paterno": "materno",
    "paciência": "impaciência",
    "paciente": "impaciente",
    "patrocinar": "boicote",
    "paz": "guerra",
    "pena": "recompensa",
    "perceptível": "imperceptível",
    "perfeição": "imperfeição",
    "permeável": "impermeável",
    "permitida": "inadmissível",
    "permissivo": "preventivo",
    "permitir": "proibido",
    "pessoal": "impessoal",
    "persuadir": "dissuadir",
    "pessimismo": "otimismo",
    "pessimista": "otimista",
    "fisica": "mental",
    "avião": "chique",
    "demandante": "réu",
    "satisfeito": "desagradado",
    "plural": "singular",
    "polar": "equatorial",
    "popular": "impopular",
    "porosidade": "solidez",
    "possibilidade": "impossibilidade",
    "posterior": "anterior",
    "potente": "impotente",
    "potencial": "real",
    "pobreza": "riqueza",
    "poderoso": "impotente",
    "elogio": "criticar",
    "preceder": "ter sucesso",
    "precedente": "sucedendo",
    "prefixo": "sufixo",
    "preparação": "resolução",
    "preparado": "despreparado",
    "prescritivo": "descritivo",
    "presença": "ausência",
    "preservado": "destruído",
    "preventivo": "permissivo",
    "primário": "secundário",
    "privado": "público",
    "em particular": "publicamente",
    "provável": "improvável",
    "produtivo": "improdutivo",
    "profano": "sagrado",
    "profissional": "amador",
    "progresso": "regredir",
    "progressivo": "regressivo",
    "prospectivo": "retrospectivo",
    "protegido": "desprotegido",
    "orgulhoso": "humilde",
    "provar": "refutar",
    "proximal": "distal",
    "próximo": "final",
    "prudente": "imprudente",
    "público": "privado",
    "publicamente": "em particular",
    "publicados": "inédito",
    "puxar": "empurrar",
    "pontualidade": "atraso",
    "purga": "reabilitar",
    "pureza": "impureza",
    "empurrar": "puxar",
    "qualificar": "desqualificar",
    "rainha": "rei",
    "questionável": "inquestionável",
    "rapidamente": "lentamente",
    "levantar": "mais baixo",
    "racional": "irracional",
    "realista": "irrealista",
    "tranquilizar": "preocupação",
    "recordar": "questão",
    "registro": "apagar",
    "refrão": "aja",
    "recusar": "aceitar",
    "regredir": "progresso",
    "regressivo": "progressivo",
    "regular": "irregular",
    "regularidade": "irregularidade",
    "regulamentado": "não regulamentado",
    "reabilitar": "purga",
    "rejeição": "aceitação",
    "rejuvenescer": "era",
    "relacionado": "não relacionado",
    "relativo": "absoluto",
    "relevante": "irrelevante",
    "confiável": "não confiável",
    "religioso": "secular",
    "repulsão": "atração",
    "respeitável": "infeliz",
    "reputação": "descrédito",
    "resistir": "entrega",
    "resolução": "preparação",
    "respeito": "desrespeito",
    "respeitoso": "desrespeitoso",
    "responsável": "irresponsável",
    "restringido": "sem restrições",
    "restrito": "sem restrições",
    "retrospectivo": "prospectivo",
    "reverente": "irreverente",
    "reversão": "afirmação",
    "recompensa": "pena",
    "passeio": "andar",
    "maduro": "verde",
    "aumentar": "queda",
    "rotor": "estator",
    "rugosidade": "suavidade",
    "volta": "quadrado",
    "arredondado": "angular",
    "rural": "urbano",
    "pressa": "demorar",
    "sagrado": "profano",
    "infelizmente": "alegremente",
    "tristeza": "alegria",
    "infelicidade": "felicidade",
    "seguro": "perigoso",
    "segurança": "insegurança",
    "semelhança": "diferença",
    "sã": "insano",
    "sanidade": "insanidade",
    "satisfação": "insatisfação",
    "salgados": "desagradável",
    "escasso": "abundante",
    "escassez": "abundância",
    "científico": "não científico",
    "escrupuloso": "sem escrúpulos",
    "secundário": "primário",
    "secular": "religioso",
    "separação": "união",
    "egoísta": "altruísta",
    "vender": "comprar",
    "senior": "júnior",
    "separado": "junta",
    "séptico": "antisséptico",
    "serviço": "desserviço",
    "resolvido": "inesgotável",
    "aguçar": "aplainar",
    "curto": "alta",
    "encurtar": "alongar",
    "gritar": "sussurro",
    "exposição": "ocultar",
    "encolher": "esticam",
    "lado": "inferior",
    "topo": "inferior",
    "significado": "insignificância",
    "significativo": "insignificante",
    "semelhante": "diferente",
    "simples": "composto",
    "simplificar": "complicar",
    "solteiro": "casado",
    "singular": "plural",
    "pia": "fonte",
    "irmã": "irmão",
    "dormir": "despertar",
    "lentamente": "rapidamente",
    "pequeno": "ampla",
    "suavidade": "rugosidade",
    "suavidade": "nitidez",
    "solidez": "porosidade",
    "solúvel": "insolúvel",
    "solvência": "insolvência",
    "solvente": "insolvente",
    "filho": "filha",
    "triste": "alegre",
    "falada": "escrito",
    "não escrito": "escrito",
    "esporádico": "contínuo",
    "espalhar": "reunir",
    "quadrado": "volta",
    "estabilidade": "instabilidade",
    "estável": "instável",
    "ficar de pé": "produção",
    "começar": "pare",
    "estator": "rotor",
    "fique": "mover",
    "íngreme": "gradual",
    "de repente": "gradual",
    "estéril": "fertil",
    "endurecer": "afrouxar",
    "mesquinho": "generoso",
    "tormentoso": "calma",
    "direto": "curvado",
    "endireitar": "dobrar",
    "desconhecido": "familiar",
    "força": "fraqueza",
    "esticam": "encolher",
    "fortemente": "fracamente",
    "estúdio": "localização",
    "estupidez": "inteligência",
    "subjetivo": "objetivo",
    "subordinar": "dominante",
    "subseqüente": "antecedente",
    "substantivo": "adjetivo",
    "subtrair": "adicionar",
    "subtração": "adição",
    "sucedendo": "precedente",
    "sucesso": "falha",
    "bem sucedido": "mal sucedido",
    "sucumbir": "sobreviver",
    "sofra": "apreciar",
    "suficiência": "insuficiência",
    "suficiente": "insuficiente",
    "suficientemente": "insuficientemente",
    "sufixo": "prefixo",
    "nascer do sol": "por do sol",
    "por do sol": "nascer do sol",
    "superior": "inferior",
    "superioridade": "inferioridade",
    "fornecem": "exigem",
    "apoiado": "não suportado",
    "superfície": "a sobrecarga",
    "entrega": "resistir",
    "sobreviver": "sucumbir",
    "doce": "azedar",
    "molhado": "seco",
    "adoçar": "azedar",
    "simetria": "assimetria",
    "simpático": "antipático",
    "sinérgico": "antagônico",
    "síntese": "análise",
    "sintético": "analítico",
    "atraso": "pontualidade",
    "de bom gosto": "insípido",
    "saboroso": "insípido",
    "insípido": "saboroso",
    "concurso": "resistente",
    "tenso": "relaxado",
    "terminal": "intermediário",
    "teísmo": "ateísmo",
    "teórico": "empírico",
    "com sede": "com fome",
    "pensativo": "irrefletido",
    "irrefletido": "pensativo",
    "econômico": "desperdício",
    "maré": "ebb",
    "gravata": "desatar",
    "tímido": "negrito",
    "timidez": "ousadia",
    "tolerância": "intolerância",
    "tolerante": "intolerante",
    "denteado": "desdentado",
    "desdentado": "denteado",
    "tocou": "intocado",
    "resistente": "concurso",
    "tratável": "intratável",
    "tragédia": "comédia",
    "treinado": "não treinado",
    "confiar em": "desconfiança",
    "verdade": "falsidade",
    "feiúra": "beleza",
    "feio": "bonita",
    "inaceitável": "aceitável",
    "não reconhecido": "reconhecido",
    "inalterado": "mudou",
    "sem ambiguidade": "ambíguo",
    "desarmado": "armado",
    "não autorizado": "autorizado",
    "desequilibrado": "equilibrado",
    "incredulidade": "crença",
    "não consolidado": "limite",
    "inquebrável": "quebrável",
    "inteiro": "partido",
    "incerteza": "certeza",
    "tio": "tia",
    "incomum": "usual",
    "despreocupado": "preocupado",
    "não confirmado": "confirmado",
    "desconectado": "conectado",
    "inconsciência": "consciência",
    "inconstitucional": "constitucional",
    "não convencional": "convencional",
    "não convencido": "convencido",
    "descobrir": "tampa",
    "sem cortes": "cortar",
    "indefinido": "definiram",
    "subestimar": "superestimar",
    "indesejável": "desejável",
    "indevida": "vencimento",
    "sem instrução": "educado",
    "inequívoca": "equívoco",
    "sem intercorrências": "agitado",
    "inesperado": "esperado",
    "infiel": "fiel",
    "desfavorável": "favorável",
    "desdobrar": "dobra",
    "ingrato": "grato",
    "pouco saudável": "saudável",
    "impiedade": "piedosos",
    "sem importância": "importante",
    "não melhorado": "melhorado",
    "desinformado": "informado",
    "desabafado": "habitado",
    "ininteligível": "inteligível",
    "não intencional": "pretendido",
    "sem querer": "intencionalmente",
    "desinteressado": "interessado",
    "desinteressante": "interessante",
    "união": "separação",
    "unitário": "federal",
    "unidos": "dividido",
    "ilimitado": "limitado",
    "desbloquear": "bloqueio",
    "azarado": "por sorte",
    "sem marca": "marcado",
    "desmascarar": "mascarar",
    "desocupado": "ocupado",
    "não oficial": "oficial",
    "sem oposição": "opôs-se",
    "pouco ortodoxo": "ortodoxo",
    "descompactar": "pacote",
    "impopular": "popular",
    "despreparado": "preparado",
    "improdutivo": "produtivo",
    "desprotegido": "protegido",
    "inédito": "publicados",
    "inquestionável": "questionável",
    "irrealista": "realista",
    "não regulamentado": "regulamentado",
    "não relacionado": "relacionado",
    "não confiável": "confiável",
    "sem restrições": "restrito",
    "não científico": "científico",
    "sem escrúpulos": "escrupuloso",
    "altruísta": "egoísta",
    "inesgotável": "resolvido",
    "instável": "estável",
    "mal sucedido": "bem sucedido",
    "não suportado": "apoiado",
    "antipático": "simpático",
    "desatar": "gravata",
    "intocado": "tocou",
    "não treinado": "treinado",
    "desvendar": "véu",
    "de forma involuntária": "de boa vontade",
    "falta de vontade": "disposição",
    "relaxar": "vento",
    "indigno": "digno",
    "urbano": "rural",
    "usual": "incomum",
    "valioso": "inútil",
    "véu": "desvendar",
    "verbal": "numérico",
    "vitória": "derrota",
    "virtuoso": "perverso",
    "visibilidade": "invisibilidade",
    "visível": "invisível",
    "vocal": "instrumental",
    "voluntário": "involuntário",
    "vogal": "consoante",
    "despertar": "dormir",
    "andar": "passeio",
    "piora": "cera",
    "guerra": "paz",
    "cauteloso": "imprudente",
    "desperdício": "econômico",
    "cera": "piora",
    "fracamente": "fortemente",
    "fraqueza": "força",
    "riqueza": "pobreza",
    "sem peso": "pesado",
    "pesado": "sem peso",
    "sussurro": "gritar",
    "branco": "preto",
    "completamente": "parcialmente",
    "perverso": "virtuoso",
    "largo": "limitar",
    "ampliar": "limitar",
    "de boa vontade": "de forma involuntária",
    "disposição": "falta de vontade",
    "vento": "relaxar",
    "sabedoria": "loucura",
    "sensato": "insensato",
    "retirar o": "depósito",
    "preocupação": "tranquilizar",
    "inútil": "valioso",
    "digno": "indigno",
    "escrito": "não escrito",
    "jovem": "idade",
    "zênite": "nadir",
}
